Class: SurgeAPI::Models::Account

Inherits:
Internal::Type::BaseModel show all
Defined in:
lib/surge_api/models/account.rb

Overview

Instance Attribute Summary collapse

Instance Method Summary collapse

Methods inherited from Internal::Type::BaseModel

==, #==, #[], coerce, #deconstruct_keys, #deep_to_h, dump, fields, hash, #hash, inherited, inspect, #inspect, known_fields, optional, recursively_to_h, required, #to_h, #to_json, #to_s, to_sorbet_type, #to_yaml

Methods included from Internal::Type::Converter

#coerce, coerce, #dump, dump, #inspect, inspect, meta_info, new_coerce_state, type_info

Methods included from Internal::Util::SorbetRuntimeSupport

#const_missing, #define_sorbet_constant!, #sorbet_constant_defined?, #to_sorbet_type, to_sorbet_type

Constructor Details

#initialize(id:, brand_name:, name:, organization:, time_zone:) ⇒ Object

Some parameter documentations has been truncated, see SurgeAPI::Models::Account for more details.

Response containing account information.

Parameters:

  • id (String)

    The account ID

  • brand_name (String, nil)

    The name by which the people this account communicates with know it. If not prov

  • name (String)

    The name of the account that will be visible for your internal organizational pu

  • organization (SurgeAPI::Models::Organization)

    The legal entity on whose behalf the account will be operated.

  • time_zone (String, nil)

    This is the time zone in which the account is headquartered. This time zone may



# File 'lib/surge_api/models/account.rb', line 43

Instance Attribute Details

#brand_nameString?

The name by which the people this account communicates with know it. If not provided, this will match the name field.

Returns:

  • (String, nil)


18
# File 'lib/surge_api/models/account.rb', line 18

required :brand_name, String, nil?: true

#idString

The account ID

Returns:

  • (String)


11
# File 'lib/surge_api/models/account.rb', line 11

required :id, String

#nameString

The name of the account that will be visible for your internal organizational purposes. This will also be the default public-facing brand name unless you also set a ‘brand_name`, but otherwise the account name will never be displayed anywhere outside of Surge HQ, and may include your ID for the account or anything else that may help you.

Returns:

  • (String)


28
# File 'lib/surge_api/models/account.rb', line 28

required :name, String

#organizationSurgeAPI::Models::Organization

The legal entity on whose behalf the account will be operated.



34
# File 'lib/surge_api/models/account.rb', line 34

required :organization, -> { SurgeAPI::Organization }

#time_zoneString?

This is the time zone in which the account is headquartered. This time zone may be used for compliance with TCPA restrictions on when messages may be sent.

Returns:

  • (String, nil)


41
# File 'lib/surge_api/models/account.rb', line 41

required :time_zone, String, nil?: true