Class: SurgeAPI::Models::AccountCreateParams::Organization::Address

Inherits:
Internal::Type::BaseModel show all
Defined in:
lib/surge_api/models/account_create_params.rb

Overview

See Also:

Instance Attribute Summary collapse

Method Summary

Methods inherited from Internal::Type::BaseModel

==, #==, #[], coerce, #deconstruct_keys, #deep_to_h, dump, fields, hash, #hash, inherited, #initialize, inspect, #inspect, known_fields, optional, recursively_to_h, required, #to_h, #to_json, #to_s, to_sorbet_type, #to_yaml

Methods included from Internal::Type::Converter

#coerce, coerce, #dump, dump, #inspect, inspect, meta_info, new_coerce_state, type_info

Methods included from Internal::Util::SorbetRuntimeSupport

#const_missing, #define_sorbet_constant!, #sorbet_constant_defined?, #to_sorbet_type, to_sorbet_type

Constructor Details

This class inherits a constructor from SurgeAPI::Internal::Type::BaseModel

Instance Attribute Details

#countryString?

The two character ISO 3166 country code. If none is provided, the organization’s country code will be used.

Returns:

  • (String, nil)


208
# File 'lib/surge_api/models/account_create_params.rb', line 208

optional :country, String, nil?: true

#line1String?

The first line of the address, typically the number and street name

Returns:

  • (String, nil)


214
# File 'lib/surge_api/models/account_create_params.rb', line 214

optional :line1, String, nil?: true

#line2String?

The second line of the address if needed, typically an apartment or suite number

Returns:

  • (String, nil)


220
# File 'lib/surge_api/models/account_create_params.rb', line 220

optional :line2, String, nil?: true

#localityString?

The city or locality

Returns:

  • (String, nil)


226
# File 'lib/surge_api/models/account_create_params.rb', line 226

optional :locality, String, nil?: true

#nameString?

The name to which any mail should be addressed. If none is provided, this will default to the organization’s registered_name

Returns:

  • (String, nil)


233
# File 'lib/surge_api/models/account_create_params.rb', line 233

optional :name, String, nil?: true

#postal_codeString?

The postal code

Returns:

  • (String, nil)


239
# File 'lib/surge_api/models/account_create_params.rb', line 239

optional :postal_code, String, nil?: true

#regionString?

The state or region

Returns:

  • (String, nil)


245
# File 'lib/surge_api/models/account_create_params.rb', line 245

optional :region, String, nil?: true