Class: SurgeAPI::Models::AccountCreateParams::Organization::Contact

Inherits:
Internal::Type::BaseModel show all
Defined in:
lib/surge_api/models/account_create_params.rb

Overview

See Also:

Defined Under Namespace

Modules: Title

Instance Attribute Summary collapse

Instance Method Summary collapse

Methods inherited from Internal::Type::BaseModel

==, #==, #[], coerce, #deconstruct_keys, #deep_to_h, dump, fields, hash, #hash, inherited, inspect, #inspect, known_fields, optional, recursively_to_h, required, #to_h, #to_json, #to_s, to_sorbet_type, #to_yaml

Methods included from Internal::Type::Converter

#coerce, coerce, #dump, dump, #inspect, inspect, meta_info, new_coerce_state, type_info

Methods included from Internal::Util::SorbetRuntimeSupport

#const_missing, #define_sorbet_constant!, #sorbet_constant_defined?, #to_sorbet_type, to_sorbet_type

Constructor Details

#initialize(email: nil, first_name: nil, last_name: nil, phone_number: nil, title: nil, title_other: nil) ⇒ Object

Some parameter documentations has been truncated, see SurgeAPI::Models::AccountCreateParams::Organization::Contact for more details.

An object representing an individual who can be contacted if Surge or our carrier partners have any questions about the business. If you are registering on behalf of your customer, this must be a contact from your customer’s company rather than your own. The individual will likely never be contacted unless there are issues with spam.

Parameters:

  • email (String, nil) (defaults to: nil)

    An email address at which the individual can be reached. Typically an email usin

  • first_name (String, nil) (defaults to: nil)

    The first name (or given name) of the individual

  • last_name (String, nil) (defaults to: nil)

    The last name (or family name) of the individual

  • phone_number (String, nil) (defaults to: nil)

    A phone number at which the individual can be reached (E.164 format)

  • title (Symbol, SurgeAPI::Models::AccountCreateParams::Organization::Contact::Title, nil) (defaults to: nil)

    The job title of the individual.

  • title_other (String, nil) (defaults to: nil)

    If ‘other` is provided for the `title` field, this field should be used to provi



# File 'lib/surge_api/models/account_create_params.rb', line 316

Instance Attribute Details

#emailString?

An email address at which the individual can be reached. Typically an email using the same domain name as the website URL will be preferred (e.g. with a website domain of ‘dtprecisionauto.com`, an email like `dom@dtprecisionauto.com` will be preferred over one like `dom@anothergarage.com` or `dom.toretto@gmail.com`. `dtprecisionauto@gmail.com` would also be acceptable, but not preferred)

Returns:

  • (String, nil)


279
# File 'lib/surge_api/models/account_create_params.rb', line 279

optional :email, String, nil?: true

#first_nameString?

The first name (or given name) of the individual

Returns:

  • (String, nil)


285
# File 'lib/surge_api/models/account_create_params.rb', line 285

optional :first_name, String, nil?: true

#last_nameString?

The last name (or family name) of the individual

Returns:

  • (String, nil)


291
# File 'lib/surge_api/models/account_create_params.rb', line 291

optional :last_name, String, nil?: true

#phone_numberString?

A phone number at which the individual can be reached (E.164 format)

Returns:

  • (String, nil)


297
# File 'lib/surge_api/models/account_create_params.rb', line 297

optional :phone_number, String, nil?: true

#titleSymbol, ...

The job title of the individual.



303
304
305
306
307
# File 'lib/surge_api/models/account_create_params.rb', line 303

optional :title,
enum: -> {
  SurgeAPI::AccountCreateParams::Organization::Contact::Title
},
nil?: true

#title_otherString?

If ‘other` is provided for the `title` field, this field should be used to provide the title of the individual

Returns:

  • (String, nil)


314
# File 'lib/surge_api/models/account_create_params.rb', line 314

optional :title_other, String, nil?: true