Module: SurgeAPI::Models::AccountStatus::Capability::Status
- Extended by:
- Internal::Type::Enum
- Defined in:
- lib/surge_api/models/account_status.rb
Overview
Whether the account is ready for the capability, has errors that need corrected, or is incomplete and requires missing data. If account has both missing and invalid fields, ‘error` will be preferred over `incomplete`.
Constant Summary collapse
- ERROR =
:error- INCOMPLETE =
:incomplete- READY =
:ready
Class Method Summary collapse
Methods included from Internal::Type::Enum
==, ===, coerce, dump, hash, inspect, to_sorbet_type, values
Methods included from Internal::Util::SorbetRuntimeSupport
#const_missing, #define_sorbet_constant!, #sorbet_constant_defined?, #to_sorbet_type, to_sorbet_type
Methods included from Internal::Type::Converter
#coerce, coerce, #dump, dump, #inspect, inspect, meta_info, new_coerce_state, type_info
Class Method Details
.values ⇒ Array<Symbol>
|
|
# File 'lib/surge_api/models/account_status.rb', line 98
|