Class: SurgeAPI::Models::AccountUpdateParams::Organization::Address

Inherits:
Internal::Type::BaseModel show all
Defined in:
lib/surge_api/models/account_update_params.rb,
sig/surge_api/models/account_update_params.rbs

Overview

See Also:

  • SurgeAPI::Models::AccountUpdateParams::Organization#address

Instance Attribute Summary collapse

Instance Method Summary collapse

Methods inherited from Internal::Type::BaseModel

==, #==, #[], coerce, #deconstruct_keys, #deep_to_h, dump, fields, hash, #hash, inherited, inspect, #inspect, known_fields, optional, recursively_to_h, required, #to_h, #to_json, #to_s, to_sorbet_type, #to_yaml

Methods included from Internal::Type::Converter

#coerce, coerce, #dump, dump, #inspect, inspect, meta_info, new_coerce_state, type_info

Methods included from Internal::Util::SorbetRuntimeSupport

#const_missing, #define_sorbet_constant!, #sorbet_constant_defined?, #to_sorbet_type, to_sorbet_type

Constructor Details

#initializeObject



164
# File 'sig/surge_api/models/account_update_params.rbs', line 164

def initialize: (

Instance Attribute Details

#countryString?

The two character ISO 3166 country code. If none is provided, the organization's country code will be used.

Parameters:

  • value (String, nil)

Returns:

  • (String, nil)


215
# File 'lib/surge_api/models/account_update_params.rb', line 215

optional :country, String, nil?: true

#line1String?

The first line of the address, typically the number and street name

Parameters:

  • value (String, nil)

Returns:

  • (String, nil)


221
# File 'lib/surge_api/models/account_update_params.rb', line 221

optional :line1, String, nil?: true

#line2String?

The second line of the address if needed, typically an apartment or suite number

Parameters:

  • value (String, nil)

Returns:

  • (String, nil)


227
# File 'lib/surge_api/models/account_update_params.rb', line 227

optional :line2, String, nil?: true

#localityString?

The city or locality

Parameters:

  • value (String, nil)

Returns:

  • (String, nil)


233
# File 'lib/surge_api/models/account_update_params.rb', line 233

optional :locality, String, nil?: true

#nameString?

The name to which any mail should be addressed. If none is provided, this will default to the organization's registered_name

Parameters:

  • value (String, nil)

Returns:

  • (String, nil)


240
# File 'lib/surge_api/models/account_update_params.rb', line 240

optional :name, String, nil?: true

#postal_codeString?

The postal code

Parameters:

  • value (String, nil)

Returns:

  • (String, nil)


246
# File 'lib/surge_api/models/account_update_params.rb', line 246

optional :postal_code, String, nil?: true

#regionString?

The state or region

Parameters:

  • value (String, nil)

Returns:

  • (String, nil)


252
# File 'lib/surge_api/models/account_update_params.rb', line 252

optional :region, String, nil?: true

Instance Method Details

#to_hash{

Returns:

  • ({)


174
# File 'sig/surge_api/models/account_update_params.rbs', line 174

def to_hash: -> {