Module: SurgeAPI::Models::Campaign::Include

Extended by:
Internal::Type::Enum
Defined in:
lib/surge_api/models/campaign.rb,
sig/surge_api/models/campaign.rbs

Constant Summary collapse

:links
PHONE_NUMBERS =

Returns:

:phone_numbers
AGE_GATED =

Returns:

:age_gated
DIRECT_LENDING =

Returns:

:direct_lending

Instance Method Summary collapse

Methods included from Internal::Type::Enum

==, ===, coerce, dump, hash, inspect, to_sorbet_type, values, values

Methods included from Internal::Util::SorbetRuntimeSupport

#const_missing, #define_sorbet_constant!, #sorbet_constant_defined?, #to_sorbet_type, to_sorbet_type

Methods included from Internal::Type::Converter

#coerce, coerce, #dump, dump, inspect, #inspect, meta_info, new_coerce_state, type_info

Instance Method Details

#initialize(id:, consent_flow:, description:, includes:, message_samples:, privacy_policy_url:, status:, use_cases:, volume:, link_sample: nil, terms_and_conditions_url: nil) ⇒ Object

Some parameter documentations has been truncated, see SurgeAPI::Models::Campaign for more details.

A campaign represents the context in which one or more of your phone numbers communicates with your contacts. Consent and opt-outs are tied to the campaign.

Parameters:

  • The campaign ID

  • A string explaining the method through which end users will opt in to receive me

  • An explanation of the organization's purpose and how it will be using text messa

  • A list of properties that this campaign should include. These properties can be

  • An array of 2-5 strings with examples of the messages that will be sent from thi

  • The URL of the privacy policy for the brand in question. This may be a shared pr

  • The current status of the campaign.

  • A list containing 1-5 types of messages that will be sent with this campaign.

  • This will be one of the following:

  • (defaults to: nil)

    A sample link that might be sent by this campaign. This is required when `includ

  • (defaults to: nil)

    The URL of the terms and conditions presented to end users when they opt in to m



162
163
164
165
166
167
168
169
170
171
172
# File 'lib/surge_api/models/campaign.rb', line 162

module Include
  extend SurgeAPI::Internal::Type::Enum

  LINKS = :links
  PHONE_NUMBERS = :phone_numbers
  AGE_GATED = :age_gated
  DIRECT_LENDING = :direct_lending

  # @!method self.values
  #   @return [Array<Symbol>]
end

#self?.values::Array[SurgeAPI::Models::Campaign::include_]

Returns:



83
# File 'sig/surge_api/models/campaign.rbs', line 83

def self?.values: -> ::Array[SurgeAPI::Models::Campaign::include_]