Module: SurgeAPI::Models::Campaign::Volume

Extended by:
Internal::Type::Enum
Defined in:
lib/surge_api/models/campaign.rb

Overview

This will be one of the following:

  • ‘low` - The campaign will be allowed to send up to 2000 SMS segments to T-Mobile customers each day. In this case your platform will be charged for the setup fee for a low volume number upon receipt of the API request.

  • ‘high` - The campaign will be allowed to send up to 200k SMS segments to T-Mobile customers each day, depending on the trust score assigned by The Campaign Registry. Your platform will be charged for the setup fee for a high volume number upon receipt of the API request, and phone numbers will be charged as high volume numbers going forward.

See Also:

Constant Summary collapse

HIGH =
:high
LOW =
:low

Class Method Summary collapse

Methods included from Internal::Type::Enum

==, ===, coerce, dump, hash, inspect, to_sorbet_type, values

Methods included from Internal::Util::SorbetRuntimeSupport

#const_missing, #define_sorbet_constant!, #sorbet_constant_defined?, #to_sorbet_type, to_sorbet_type

Methods included from Internal::Type::Converter

#coerce, coerce, #dump, dump, #inspect, inspect, meta_info, new_coerce_state, type_info

Class Method Details

.valuesArray<Symbol>

Returns:

  • (Array<Symbol>)


# File 'lib/surge_api/models/campaign.rb', line 203