Class: SurgeAPI::Models::CampaignParams::ExternalCampaignParams
- Inherits:
-
Internal::Type::BaseModel
- Object
- Internal::Type::BaseModel
- SurgeAPI::Models::CampaignParams::ExternalCampaignParams
- Defined in:
- lib/surge_api/models/campaign_params.rb
Instance Attribute Summary collapse
-
#tcr_id ⇒ String
The Campaign Registry (TCR) ID for the externally registered campaign.
Instance Method Summary collapse
-
#initialize(tcr_id:) ⇒ Object
constructor
Import an externally registered campaign from The Campaign Registry (TCR).
Methods inherited from Internal::Type::BaseModel
==, #==, #[], coerce, #deconstruct_keys, #deep_to_h, dump, fields, hash, #hash, inherited, inspect, #inspect, known_fields, optional, recursively_to_h, required, #to_h, #to_json, #to_s, to_sorbet_type, #to_yaml
Methods included from Internal::Type::Converter
#coerce, coerce, #dump, dump, #inspect, inspect, meta_info, new_coerce_state, type_info
Methods included from Internal::Util::SorbetRuntimeSupport
#const_missing, #define_sorbet_constant!, #sorbet_constant_defined?, #to_sorbet_type, to_sorbet_type
Constructor Details
#initialize(tcr_id:) ⇒ Object
Import an externally registered campaign from The Campaign Registry (TCR)
|
|
# File 'lib/surge_api/models/campaign_params.rb', line 218
|
Instance Attribute Details
#tcr_id ⇒ String
The Campaign Registry (TCR) ID for the externally registered campaign
216 |
# File 'lib/surge_api/models/campaign_params.rb', line 216 required :tcr_id, String |