Module: SurgeAPI::Models::CampaignParams::StandardCampaignParams::UseCase

Extended by:
Internal::Type::Enum
Defined in:
lib/surge_api/models/campaign_params.rb

Constant Summary collapse

ACCOUNT_NOTIFICATION =
:account_notification
CUSTOMER_CARE =
:customer_care
DELIVERY_NOTIFICATION =
:delivery_notification
FRAUD_ALERT =
:fraud_alert
HIGHER_EDUCATION =
:higher_education
MARKETING =
:marketing
POLLING_VOTING =
:polling_voting
PUBLIC_SERVICE_ANNOUNCEMENT =
:public_service_announcement
SECURITY_ALERT =
:security_alert
TWO_FACTOR_AUTHENTICATION =
:two_factor_authentication

Instance Method Summary collapse

Methods included from Internal::Type::Enum

==, ===, coerce, dump, hash, inspect, to_sorbet_type, values

Methods included from Internal::Util::SorbetRuntimeSupport

#const_missing, #define_sorbet_constant!, #sorbet_constant_defined?, #to_sorbet_type, to_sorbet_type

Methods included from Internal::Type::Converter

#coerce, coerce, #dump, dump, #inspect, inspect, meta_info, new_coerce_state, type_info

Instance Method Details

#initialize(consent_flow:, description:, message_samples:, privacy_policy_url:, use_cases:, volume:, includes: nil, link_sample: nil, terms_and_conditions_url: nil) ⇒ Object

Some parameter documentations has been truncated, see SurgeAPI::Models::CampaignParams::StandardCampaignParams for more details.

Full campaign details for standard registration through Surge

Parameters:

  • consent_flow (String)

    A string explaining the method through which end users will opt in to receive me

  • description (String)

    An explanation of the organization’s purpose and how it will be using text messa

  • message_samples (Array<String>)

    An array of 2-5 strings with examples of the messages that will be sent from thi

  • privacy_policy_url (String)

    The URL of the privacy policy for the brand in question. This may be a shared pr

  • use_cases (Array<Symbol, SurgeAPI::Models::CampaignParams::StandardCampaignParams::UseCase>)

    A list containing 1-5 types of messages that will be sent with this campaign.

  • volume (Symbol, SurgeAPI::Models::CampaignParams::StandardCampaignParams::Volume)

    This will be one of the following:

  • includes (Array<Symbol, SurgeAPI::Models::CampaignParams::StandardCampaignParams::Include>) (defaults to: nil)

    A list of properties that this campaign should include. These properties can be

  • link_sample (String) (defaults to: nil)

    A sample link that might be sent by this campaign. If links from other domains a

  • terms_and_conditions_url (String) (defaults to: nil)

    The URL of the terms and conditions presented to end users when they opt in to m



158
159
160
161
162
163
164
165
166
167
168
169
170
171
172
173
174
# File 'lib/surge_api/models/campaign_params.rb', line 158

module UseCase
  extend SurgeAPI::Internal::Type::Enum

  ACCOUNT_NOTIFICATION = :account_notification
  CUSTOMER_CARE = :customer_care
  DELIVERY_NOTIFICATION = :delivery_notification
  FRAUD_ALERT = :fraud_alert
  HIGHER_EDUCATION = :higher_education
  MARKETING = :marketing
  POLLING_VOTING = :polling_voting
  PUBLIC_SERVICE_ANNOUNCEMENT = :public_service_announcement
  SECURITY_ALERT = :security_alert
  TWO_FACTOR_AUTHENTICATION = :two_factor_authentication

  # @!method self.values
  #   @return [Array<Symbol>]
end