Module: SurgeAPI::Models::CampaignParams::StandardCampaignParams::Volume
- Extended by:
- Internal::Type::Enum
- Defined in:
- lib/surge_api/models/campaign_params.rb,
sig/surge_api/models/campaign_params.rbs
Overview
This will be one of the following:
low- The campaign will be allowed to send up to 2000 SMS segments to T-Mobile customers each day. In this case your platform will be charged for the setup fee for a low volume number upon receipt of the API request.high- The campaign will be allowed to send up to 200k SMS segments to T-Mobile customers each day, depending on the trust score assigned by The Campaign Registry. Your platform will be charged for the setup fee for a high volume number upon receipt of the API request, and phone numbers will be charged as high volume numbers going forward.
Constant Summary collapse
- HIGH =
:high- LOW =
:low
Instance Method Summary collapse
Methods included from Internal::Type::Enum
==, ===, coerce, dump, hash, inspect, to_sorbet_type, values, values
Methods included from Internal::Util::SorbetRuntimeSupport
#const_missing, #define_sorbet_constant!, #sorbet_constant_defined?, #to_sorbet_type, to_sorbet_type
Methods included from Internal::Type::Converter
#coerce, coerce, #dump, dump, #inspect, inspect, meta_info, new_coerce_state, type_info
Instance Method Details
#self?.values ⇒ ::Array[SurgeAPI::Models::CampaignParams::StandardCampaignParams::volume]
109 |
# File 'sig/surge_api/models/campaign_params.rbs', line 109
def self?.values: -> ::Array[SurgeAPI::Models::CampaignParams::StandardCampaignParams::volume]
|