Class: SurgeAPI::Models::ContactCreateParams
- Inherits:
-
Internal::Type::BaseModel
- Object
- Internal::Type::BaseModel
- SurgeAPI::Models::ContactCreateParams
- Extended by:
- Internal::Type::RequestParameters::Converter
- Includes:
- Internal::Type::RequestParameters
- Defined in:
- lib/surge_api/models/contact_create_params.rb,
sig/surge_api/models/contact_create_params.rbs
Overview
Instance Attribute Summary collapse
-
#account_id ⇒ String
The account for which the contact should be created.
-
#email ⇒ String?
The contact's email address.
-
#first_name ⇒ String?
The contact's first name.
-
#last_name ⇒ String?
The contact's last name.
-
#metadata ⇒ Hash{Symbol=>String}?
Set of key-value pairs that will be stored with the object.
-
#phone_number ⇒ String
The contact's phone number in E.164 format.
Attributes included from Internal::Type::RequestParameters
Instance Method Summary collapse
- #initialize(account_id:, phone_number:, email: nil, first_name: nil, last_name: nil, metadata: nil, request_options: {}) ⇒ Object constructor
- #to_hash ⇒ {
Methods included from Internal::Type::RequestParameters::Converter
Methods included from Internal::Type::RequestParameters
Methods inherited from Internal::Type::BaseModel
==, #==, #[], coerce, #deconstruct_keys, #deep_to_h, dump, fields, hash, #hash, inherited, inspect, #inspect, known_fields, optional, recursively_to_h, required, #to_h, #to_json, #to_s, to_sorbet_type, #to_yaml
Methods included from Internal::Type::Converter
#coerce, coerce, #dump, dump, #inspect, inspect, meta_info, new_coerce_state, type_info
Methods included from Internal::Util::SorbetRuntimeSupport
#const_missing, #define_sorbet_constant!, #sorbet_constant_defined?, #to_sorbet_type, to_sorbet_type
Constructor Details
#initialize(account_id:, phone_number:, email: nil, first_name: nil, last_name: nil, metadata: nil, request_options: {}) ⇒ Object
|
|
# File 'lib/surge_api/models/contact_create_params.rb', line 46
|
Instance Attribute Details
#account_id ⇒ String
The account for which the contact should be created.
14 |
# File 'lib/surge_api/models/contact_create_params.rb', line 14 required :account_id, String |
#email ⇒ String?
The contact's email address.
26 |
# File 'lib/surge_api/models/contact_create_params.rb', line 26 optional :email, String |
#first_name ⇒ String?
The contact's first name.
32 |
# File 'lib/surge_api/models/contact_create_params.rb', line 32 optional :first_name, String |
#last_name ⇒ String?
The contact's last name.
38 |
# File 'lib/surge_api/models/contact_create_params.rb', line 38 optional :last_name, String |
#metadata ⇒ Hash{Symbol=>String}?
Set of key-value pairs that will be stored with the object.
44 |
# File 'lib/surge_api/models/contact_create_params.rb', line 44 optional :metadata, SurgeAPI::Internal::Type::HashOf[String] |
#phone_number ⇒ String
The contact's phone number in E.164 format.
20 |
# File 'lib/surge_api/models/contact_create_params.rb', line 20 required :phone_number, String |
Instance Method Details
#to_hash ⇒ {
48 |
# File 'sig/surge_api/models/contact_create_params.rbs', line 48
def to_hash: -> {
|