Class: SurgeAPI::Models::ConversationCreatedWebhookEvent

Inherits:
Internal::Type::BaseModel show all
Defined in:
lib/surge_api/models/conversation_created_webhook_event.rb

Defined Under Namespace

Classes: Data

Instance Attribute Summary collapse

Instance Method Summary collapse

Methods inherited from Internal::Type::BaseModel

==, #==, #[], coerce, #deconstruct_keys, #deep_to_h, dump, fields, hash, #hash, inherited, inspect, #inspect, known_fields, optional, recursively_to_h, required, #to_h, #to_json, #to_s, to_sorbet_type, #to_yaml

Methods included from Internal::Type::Converter

#coerce, coerce, #dump, dump, #inspect, inspect, meta_info, new_coerce_state, type_info

Methods included from Internal::Util::SorbetRuntimeSupport

#const_missing, #define_sorbet_constant!, #sorbet_constant_defined?, #to_sorbet_type, to_sorbet_type

Constructor Details

#initialize(account_id:, data:, timestamp:, type: :"conversation.created") ⇒ Object

Parameters:

  • account_id (String)

    The ID of the account in which this event occurred

  • data (SurgeAPI::Models::ConversationCreatedWebhookEvent::Data)

    The data associated with the event

  • timestamp (Time)

    The timestamp when this event occurred, in ISO8601 format

  • type (Symbol, :"conversation.created") (defaults to: :"conversation.created")

    The type of the event. Always ‘conversation.created` for this event.



# File 'lib/surge_api/models/conversation_created_webhook_event.rb', line 30

Instance Attribute Details

#account_idString

The ID of the account in which this event occurred

Returns:

  • (String)


10
# File 'lib/surge_api/models/conversation_created_webhook_event.rb', line 10

required :account_id, String

#dataSurgeAPI::Models::ConversationCreatedWebhookEvent::Data

The data associated with the event



16
# File 'lib/surge_api/models/conversation_created_webhook_event.rb', line 16

required :data, -> { SurgeAPI::ConversationCreatedWebhookEvent::Data }

#timestampTime

The timestamp when this event occurred, in ISO8601 format

Returns:

  • (Time)


22
# File 'lib/surge_api/models/conversation_created_webhook_event.rb', line 22

required :timestamp, Time

#typeSymbol, :"conversation.created"

The type of the event. Always ‘conversation.created` for this event.

Returns:

  • (Symbol, :"conversation.created")


28
# File 'lib/surge_api/models/conversation_created_webhook_event.rb', line 28

required :type, const: :"conversation.created"