Class: SurgeAPI::Models::LinkFollowedWebhookEvent::Data

Inherits:
Internal::Type::BaseModel show all
Defined in:
lib/surge_api/models/link_followed_webhook_event.rb

Overview

See Also:

Instance Attribute Summary collapse

Instance Method Summary collapse

Methods inherited from Internal::Type::BaseModel

==, #==, #[], coerce, #deconstruct_keys, #deep_to_h, dump, fields, hash, #hash, inherited, inspect, #inspect, known_fields, optional, recursively_to_h, required, #to_h, #to_json, #to_s, to_sorbet_type, #to_yaml

Methods included from Internal::Type::Converter

#coerce, coerce, #dump, dump, #inspect, inspect, meta_info, new_coerce_state, type_info

Methods included from Internal::Util::SorbetRuntimeSupport

#const_missing, #define_sorbet_constant!, #sorbet_constant_defined?, #to_sorbet_type, to_sorbet_type

Constructor Details

#initialize(id:, message:, message_id:, url:) ⇒ Object

The data associated with the event

Parameters:

  • id (String)

    The unique identifier for the link

  • message (SurgeAPI::Models::Message, nil)

    A Message is a communication sent to a Contact.

  • message_id (String, nil)

    Deprecated. The unique identifier for the message that contained the link.

  • url (String)

    The original URL that was shortened



# File 'lib/surge_api/models/link_followed_webhook_event.rb', line 67

Instance Attribute Details

#idString

The unique identifier for the link

Returns:

  • (String)


45
# File 'lib/surge_api/models/link_followed_webhook_event.rb', line 45

required :id, String

#messageSurgeAPI::Models::Message?

A Message is a communication sent to a Contact.

Returns:



51
# File 'lib/surge_api/models/link_followed_webhook_event.rb', line 51

required :message, -> { SurgeAPI::Message }, nil?: true

#message_idString?

Deprecated.

Use ‘message.id` instead.

Deprecated. The unique identifier for the message that contained the link.

Returns:

  • (String, nil)


59
# File 'lib/surge_api/models/link_followed_webhook_event.rb', line 59

required :message_id, String, nil?: true

#urlString

The original URL that was shortened

Returns:

  • (String)


65
# File 'lib/surge_api/models/link_followed_webhook_event.rb', line 65

required :url, String