Class: SurgeAPI::Models::Message::Conversation
- Inherits:
-
Internal::Type::BaseModel
- Object
- Internal::Type::BaseModel
- SurgeAPI::Models::Message::Conversation
- Defined in:
- lib/surge_api/models/message.rb
Overview
Defined Under Namespace
Classes: PhoneNumber
Instance Attribute Summary collapse
-
#contact ⇒ SurgeAPI::Models::Contact
A contact who has consented to receive messages.
-
#id ⇒ String
Unique identifier for the object.
-
#phone_number ⇒ SurgeAPI::Models::Message::Conversation::PhoneNumber?
This is the phone number tied to the Surge account.
Instance Method Summary collapse
-
#initialize(id:, contact:, phone_number: nil) ⇒ Object
constructor
A conversation with a Contact.
Methods inherited from Internal::Type::BaseModel
==, #==, #[], coerce, #deconstruct_keys, #deep_to_h, dump, fields, hash, #hash, inherited, inspect, #inspect, known_fields, optional, recursively_to_h, required, #to_h, #to_json, #to_s, to_sorbet_type, #to_yaml
Methods included from Internal::Type::Converter
#coerce, coerce, #dump, dump, #inspect, inspect, meta_info, new_coerce_state, type_info
Methods included from Internal::Util::SorbetRuntimeSupport
#const_missing, #define_sorbet_constant!, #sorbet_constant_defined?, #to_sorbet_type, to_sorbet_type
Constructor Details
#initialize(id:, contact:, phone_number: nil) ⇒ Object
A conversation with a Contact
|
|
# File 'lib/surge_api/models/message.rb', line 110
|
Instance Attribute Details
#contact ⇒ SurgeAPI::Models::Contact
A contact who has consented to receive messages
102 |
# File 'lib/surge_api/models/message.rb', line 102 required :contact, -> { SurgeAPI::Contact } |
#id ⇒ String
Unique identifier for the object.
96 |
# File 'lib/surge_api/models/message.rb', line 96 required :id, String |
#phone_number ⇒ SurgeAPI::Models::Message::Conversation::PhoneNumber?
This is the phone number tied to the Surge account.
108 |
# File 'lib/surge_api/models/message.rb', line 108 optional :phone_number, -> { SurgeAPI::Message::Conversation::PhoneNumber } |