Class: SurgeAPI::Models::Message::Conversation::PhoneNumber
- Inherits:
-
Internal::Type::BaseModel
- Object
- Internal::Type::BaseModel
- SurgeAPI::Models::Message::Conversation::PhoneNumber
- Defined in:
- lib/surge_api/models/message.rb
Overview
Defined Under Namespace
Modules: Type
Instance Attribute Summary collapse
-
#id ⇒ String
Unique identifier for the phone number.
-
#number ⇒ String
The canonical format of the phone number.
-
#type ⇒ Symbol, SurgeAPI::Models::Message::Conversation::PhoneNumber::Type
Whether the phone number is local, toll-free, or short code.
Instance Method Summary collapse
-
#initialize(id:, number:, type:) ⇒ Object
constructor
This is the phone number tied to the Surge account.
Methods inherited from Internal::Type::BaseModel
==, #==, #[], coerce, #deconstruct_keys, #deep_to_h, dump, fields, hash, #hash, inherited, inspect, #inspect, known_fields, optional, recursively_to_h, required, #to_h, #to_json, #to_s, to_sorbet_type, #to_yaml
Methods included from Internal::Type::Converter
#coerce, coerce, #dump, dump, #inspect, inspect, meta_info, new_coerce_state, type_info
Methods included from Internal::Util::SorbetRuntimeSupport
#const_missing, #define_sorbet_constant!, #sorbet_constant_defined?, #to_sorbet_type, to_sorbet_type
Constructor Details
#initialize(id:, number:, type:) ⇒ Object
This is the phone number tied to the Surge account.
|
|
# File 'lib/surge_api/models/message.rb', line 139
|
Instance Attribute Details
#id ⇒ String
Unique identifier for the phone number
125 |
# File 'lib/surge_api/models/message.rb', line 125 required :id, String |
#number ⇒ String
The canonical format of the phone number.
131 |
# File 'lib/surge_api/models/message.rb', line 131 required :number, String |
#type ⇒ Symbol, SurgeAPI::Models::Message::Conversation::PhoneNumber::Type
Whether the phone number is local, toll-free, or short code
137 |
# File 'lib/surge_api/models/message.rb', line 137 required :type, enum: -> { SurgeAPI::Message::Conversation::PhoneNumber::Type } |