Class: SurgeAPI::Models::MessageDeliveredWebhookEvent::Data::Conversation
- Inherits:
-
Internal::Type::BaseModel
- Object
- Internal::Type::BaseModel
- SurgeAPI::Models::MessageDeliveredWebhookEvent::Data::Conversation
- Defined in:
- lib/surge_api/models/message_delivered_webhook_event.rb
Overview
Instance Attribute Summary collapse
-
#contact ⇒ SurgeAPI::Models::Contact
A contact who has consented to receive messages.
-
#id ⇒ String
The unique identifier for the conversation.
-
#phone_number ⇒ SurgeAPI::Models::PhoneNumber
A phone number that can be used to send and receive messages and calls.
Method Summary
Methods inherited from Internal::Type::BaseModel
==, #==, #[], coerce, #deconstruct_keys, #deep_to_h, dump, fields, hash, #hash, inherited, #initialize, inspect, #inspect, known_fields, optional, recursively_to_h, required, #to_h, #to_json, #to_s, to_sorbet_type, #to_yaml
Methods included from Internal::Type::Converter
#coerce, coerce, #dump, dump, #inspect, inspect, meta_info, new_coerce_state, type_info
Methods included from Internal::Util::SorbetRuntimeSupport
#const_missing, #define_sorbet_constant!, #sorbet_constant_defined?, #to_sorbet_type, to_sorbet_type
Constructor Details
This class inherits a constructor from SurgeAPI::Internal::Type::BaseModel
Instance Attribute Details
#contact ⇒ SurgeAPI::Models::Contact
A contact who has consented to receive messages
109 |
# File 'lib/surge_api/models/message_delivered_webhook_event.rb', line 109 required :contact, -> { SurgeAPI::Contact } |
#id ⇒ String
The unique identifier for the conversation
103 |
# File 'lib/surge_api/models/message_delivered_webhook_event.rb', line 103 required :id, String |
#phone_number ⇒ SurgeAPI::Models::PhoneNumber
A phone number that can be used to send and receive messages and calls
115 |
# File 'lib/surge_api/models/message_delivered_webhook_event.rb', line 115 required :phone_number, -> { SurgeAPI::PhoneNumber } |