Class: SurgeAPI::Models::MessageFailedWebhookEvent::Data

Inherits:
Internal::Type::BaseModel show all
Defined in:
lib/surge_api/models/message_failed_webhook_event.rb

Overview

See Also:

Defined Under Namespace

Classes: Attachment, Conversation

Instance Attribute Summary collapse

Instance Method Summary collapse

Methods inherited from Internal::Type::BaseModel

==, #==, #[], coerce, #deconstruct_keys, #deep_to_h, dump, fields, hash, #hash, inherited, inspect, #inspect, known_fields, optional, recursively_to_h, required, #to_h, #to_json, #to_s, to_sorbet_type, #to_yaml

Methods included from Internal::Type::Converter

#coerce, coerce, #dump, dump, #inspect, inspect, meta_info, new_coerce_state, type_info

Methods included from Internal::Util::SorbetRuntimeSupport

#const_missing, #define_sorbet_constant!, #sorbet_constant_defined?, #to_sorbet_type, to_sorbet_type

Constructor Details

#initialize(id:, contact:, phone_number:) ⇒ Object

The conversation this message belongs to

Parameters:



# File 'lib/surge_api/models/message_failed_webhook_event.rb', line 85

Instance Attribute Details

#attachmentsArray<SurgeAPI::Models::MessageFailedWebhookEvent::Data::Attachment>?

Attachments included with the message



75
76
# File 'lib/surge_api/models/message_failed_webhook_event.rb', line 75

optional :attachments,
-> { SurgeAPI::Internal::Type::ArrayOf[SurgeAPI::MessageFailedWebhookEvent::Data::Attachment] }

#blast_idString?

The ID of the blast this message belongs to, if any. This can be used to attribute messages back to a specific blast.

Returns:

  • (String, nil)


83
# File 'lib/surge_api/models/message_failed_webhook_event.rb', line 83

optional :blast_id, String

#bodyString?

The content of the message

Returns:

  • (String, nil)


51
# File 'lib/surge_api/models/message_failed_webhook_event.rb', line 51

required :body, String, nil?: true

#conversationSurgeAPI::Models::MessageFailedWebhookEvent::Data::Conversation

The conversation this message belongs to



57
# File 'lib/surge_api/models/message_failed_webhook_event.rb', line 57

required :conversation, -> { SurgeAPI::MessageFailedWebhookEvent::Data::Conversation }

#failed_atTime

When the message failed

Returns:

  • (Time)


63
# File 'lib/surge_api/models/message_failed_webhook_event.rb', line 63

required :failed_at, Time

#failure_reasonString

The reason the message failed to be delivered

Returns:

  • (String)


69
# File 'lib/surge_api/models/message_failed_webhook_event.rb', line 69

required :failure_reason, String

#idString

The unique identifier for the message

Returns:

  • (String)


45
# File 'lib/surge_api/models/message_failed_webhook_event.rb', line 45

required :id, String