Module: SurgeAPI::Models::MessageParams
- Extended by:
- Internal::Type::Union
- Defined in:
- lib/surge_api/models/message_params.rb,
sig/surge_api/models/message_params.rbs
Overview
Payload for creating a message. Either an attachment or the body must be given. You can specify the recipient either using the 'conversation' parameter or the 'to'/'from' parameters, but not both.
Defined Under Namespace
Classes: MessageParamsWithConversation, SimpleMessageParams
Class Method Summary collapse
- .values ⇒ Array<Symbol>
- .variants ⇒ Array(SurgeAPI::Models::MessageParams::MessageParamsWithConversation, SurgeAPI::Models::MessageParams::SimpleMessageParams)
Instance Method Summary collapse
Methods included from Internal::Type::Union
==, ===, coerce, derefed_variants, dump, hash, inspect, to_sorbet_type, variants
Methods included from Internal::Util::SorbetRuntimeSupport
#const_missing, #define_sorbet_constant!, #sorbet_constant_defined?, #to_sorbet_type, to_sorbet_type
Methods included from Internal::Type::Converter
#coerce, coerce, #dump, dump, #inspect, inspect, meta_info, new_coerce_state, type_info
Class Method Details
.values ⇒ Array<Symbol>
|
|
# File 'lib/surge_api/models/message_params.rb', line 186
|
.variants ⇒ Array(SurgeAPI::Models::MessageParams::MessageParamsWithConversation, SurgeAPI::Models::MessageParams::SimpleMessageParams)
|
|
# File 'lib/surge_api/models/message_params.rb', line 300
|
Instance Method Details
#self?.variants ⇒ ::Array[SurgeAPI::Models::message_params]
282 |
# File 'sig/surge_api/models/message_params.rbs', line 282
def self?.variants: -> ::Array[SurgeAPI::Models::message_params]
|