Class: SurgeAPI::Models::MessageParams::MessageParamsWithConversation::Conversation

Inherits:
Internal::Type::BaseModel show all
Defined in:
lib/surge_api/models/message_params.rb

Overview

See Also:

Defined Under Namespace

Classes: Contact

Instance Attribute Summary collapse

Instance Method Summary collapse

Methods inherited from Internal::Type::BaseModel

==, #==, #[], coerce, #deconstruct_keys, #deep_to_h, dump, fields, hash, #hash, inherited, inspect, #inspect, known_fields, optional, recursively_to_h, required, #to_h, #to_json, #to_s, to_sorbet_type, #to_yaml

Methods included from Internal::Type::Converter

#coerce, coerce, #dump, dump, #inspect, inspect, meta_info, new_coerce_state, type_info

Methods included from Internal::Util::SorbetRuntimeSupport

#const_missing, #define_sorbet_constant!, #sorbet_constant_defined?, #to_sorbet_type, to_sorbet_type

Constructor Details

#initialize(contact:, phone_number: nil) ⇒ Object

Some parameter documentations has been truncated, see SurgeAPI::Models::MessageParams::MessageParamsWithConversation::Conversation for more details.

Params for selecting or creating a new conversation. Either the id or the Contact must be given.

Parameters:



# File 'lib/surge_api/models/message_params.rb', line 83

Instance Attribute Details

#contactSurgeAPI::Models::MessageParams::MessageParamsWithConversation::Conversation::Contact

Parameters for creating a contact



74
# File 'lib/surge_api/models/message_params.rb', line 74

required :contact, -> { SurgeAPI::MessageParams::MessageParamsWithConversation::Conversation::Contact }

#phone_numberString?

The phone number from which to send the message. This can be either the phone number in E.164 format or a Surge phone number id.

Returns:

  • (String, nil)


81
# File 'lib/surge_api/models/message_params.rb', line 81

optional :phone_number, String