Class: SurgeAPI::Models::MessageParams::MessageParamsWithConversation::Conversation::Contact
- Inherits:
-
Internal::Type::BaseModel
- Object
- Internal::Type::BaseModel
- SurgeAPI::Models::MessageParams::MessageParamsWithConversation::Conversation::Contact
- Defined in:
- lib/surge_api/models/message_params.rb,
sig/surge_api/models/message_params.rbs
Overview
Instance Attribute Summary collapse
-
#email ⇒ String?
The contact's email address.
-
#first_name ⇒ String?
The contact's first name.
-
#last_name ⇒ String?
The contact's last name.
-
#metadata ⇒ Hash{Symbol=>String}?
Set of key-value pairs that will be stored with the object.
-
#phone_number ⇒ String
The contact's phone number in E.164 format.
Instance Method Summary collapse
- #initialize ⇒ Object constructor
- #to_hash ⇒ {
Methods inherited from Internal::Type::BaseModel
==, #==, #[], coerce, #deconstruct_keys, #deep_to_h, dump, fields, hash, #hash, inherited, inspect, #inspect, known_fields, optional, recursively_to_h, required, #to_h, #to_json, #to_s, to_sorbet_type, #to_yaml
Methods included from Internal::Type::Converter
#coerce, coerce, #dump, dump, #inspect, inspect, meta_info, new_coerce_state, type_info
Methods included from Internal::Util::SorbetRuntimeSupport
#const_missing, #define_sorbet_constant!, #sorbet_constant_defined?, #to_sorbet_type, to_sorbet_type
Constructor Details
#initialize ⇒ Object
116 |
# File 'sig/surge_api/models/message_params.rbs', line 116
def initialize: (
|
Instance Attribute Details
#email ⇒ String?
The contact's email address.
115 |
# File 'lib/surge_api/models/message_params.rb', line 115 optional :email, String |
#first_name ⇒ String?
The contact's first name.
121 |
# File 'lib/surge_api/models/message_params.rb', line 121 optional :first_name, String |
#last_name ⇒ String?
The contact's last name.
127 |
# File 'lib/surge_api/models/message_params.rb', line 127 optional :last_name, String |
#metadata ⇒ Hash{Symbol=>String}?
Set of key-value pairs that will be stored with the object.
133 |
# File 'lib/surge_api/models/message_params.rb', line 133 optional :metadata, SurgeAPI::Internal::Type::HashOf[String] |
#phone_number ⇒ String
The contact's phone number in E.164 format.
109 |
# File 'lib/surge_api/models/message_params.rb', line 109 required :phone_number, String |
Instance Method Details
#to_hash ⇒ {
124 |
# File 'sig/surge_api/models/message_params.rbs', line 124
def to_hash: -> {
|