Class: SurgeAPI::Models::MessageParams::SimpleMessageParams
- Inherits:
-
Internal::Type::BaseModel
- Object
- Internal::Type::BaseModel
- SurgeAPI::Models::MessageParams::SimpleMessageParams
- Defined in:
- lib/surge_api/models/message_params.rb,
sig/surge_api/models/message_params.rbs
Defined Under Namespace
Classes: Attachment, Settings
Instance Attribute Summary collapse
- #attachments ⇒ Array<SurgeAPI::Models::MessageParams::SimpleMessageParams::Attachment>?
-
#body ⇒ String?
The message body.
-
#from ⇒ String?
The sender's phone number in E.164 format or phone number ID.
-
#metadata ⇒ Hash{Symbol=>String}?
Set of key-value pairs that will be stored with the object.
-
#send_at ⇒ Time?
An optional datetime for scheduling message up to a couple of months in the future.
-
#settings ⇒ SurgeAPI::Models::MessageParams::SimpleMessageParams::Settings?
Per-message setting overrides.
-
#to ⇒ String
The recipient's phone number in E.164 format.
Instance Method Summary collapse
-
#initialize(url:) ⇒ Object
constructor
Params for creating an attachment.
- #to_hash ⇒ {
Methods inherited from Internal::Type::BaseModel
==, #==, #[], coerce, #deconstruct_keys, #deep_to_h, dump, fields, hash, #hash, inherited, inspect, #inspect, known_fields, optional, recursively_to_h, required, #to_h, #to_json, #to_s, to_sorbet_type, #to_yaml
Methods included from Internal::Type::Converter
#coerce, coerce, #dump, dump, #inspect, inspect, meta_info, new_coerce_state, type_info
Methods included from Internal::Util::SorbetRuntimeSupport
#const_missing, #define_sorbet_constant!, #sorbet_constant_defined?, #to_sorbet_type, to_sorbet_type
Constructor Details
#initialize(url:) ⇒ Object
Params for creating an attachment
|
|
# File 'lib/surge_api/models/message_params.rb', line 273
|
Instance Attribute Details
#attachments ⇒ Array<SurgeAPI::Models::MessageParams::SimpleMessageParams::Attachment>?
211 212 |
# File 'lib/surge_api/models/message_params.rb', line 211 optional :attachments, -> { SurgeAPI::Internal::Type::ArrayOf[SurgeAPI::MessageParams::SimpleMessageParams::Attachment] } |
#body ⇒ String?
The message body.
218 |
# File 'lib/surge_api/models/message_params.rb', line 218 optional :body, String |
#from ⇒ String?
The sender's phone number in E.164 format or phone number ID. If omitted, uses the account's default phone number. Cannot be used together with 'conversation'.
225 |
# File 'lib/surge_api/models/message_params.rb', line 225 optional :from, String |
#metadata ⇒ Hash{Symbol=>String}?
Set of key-value pairs that will be stored with the object.
231 |
# File 'lib/surge_api/models/message_params.rb', line 231 optional :metadata, SurgeAPI::Internal::Type::HashOf[String] |
#send_at ⇒ Time?
An optional datetime for scheduling message up to a couple of months in the future.
238 |
# File 'lib/surge_api/models/message_params.rb', line 238 optional :send_at, Time |
#settings ⇒ SurgeAPI::Models::MessageParams::SimpleMessageParams::Settings?
Per-message setting overrides.
244 |
# File 'lib/surge_api/models/message_params.rb', line 244 optional :settings, -> { SurgeAPI::MessageParams::SimpleMessageParams::Settings } |
#to ⇒ String
The recipient's phone number in E.164 format. Cannot be used together with 'conversation'.
206 |
# File 'lib/surge_api/models/message_params.rb', line 206 required :to, String |
Instance Method Details
#to_hash ⇒ {
236 |
# File 'sig/surge_api/models/message_params.rbs', line 236
def to_hash: -> {
|