Class: SurgeAPI::Models::MessageSentWebhookEvent::Data::Conversation
- Inherits:
-
Internal::Type::BaseModel
- Object
- Internal::Type::BaseModel
- SurgeAPI::Models::MessageSentWebhookEvent::Data::Conversation
- Defined in:
- lib/surge_api/models/message_sent_webhook_event.rb,
sig/surge_api/models/message_sent_webhook_event.rbs
Overview
Instance Attribute Summary collapse
-
#contact ⇒ SurgeAPI::Models::Contact
A contact who has consented to receive messages.
-
#id ⇒ String
The unique identifier for the conversation.
-
#phone_number ⇒ SurgeAPI::Models::PhoneNumber
A phone number that can be used to send and receive messages and calls.
Instance Method Summary collapse
- #initialize ⇒ Object constructor
- #to_hash ⇒ {
Methods inherited from Internal::Type::BaseModel
==, #==, #[], coerce, #deconstruct_keys, #deep_to_h, dump, fields, hash, #hash, inherited, inspect, #inspect, known_fields, optional, recursively_to_h, required, #to_h, #to_json, #to_s, to_sorbet_type, #to_yaml
Methods included from Internal::Type::Converter
#coerce, coerce, #dump, dump, #inspect, inspect, meta_info, new_coerce_state, type_info
Methods included from Internal::Util::SorbetRuntimeSupport
#const_missing, #define_sorbet_constant!, #sorbet_constant_defined?, #to_sorbet_type, to_sorbet_type
Constructor Details
#initialize ⇒ Object
100 |
# File 'sig/surge_api/models/message_sent_webhook_event.rbs', line 100
def initialize: (
|
Instance Attribute Details
#contact ⇒ SurgeAPI::Models::Contact
A contact who has consented to receive messages
117 |
# File 'lib/surge_api/models/message_sent_webhook_event.rb', line 117 required :contact, -> { SurgeAPI::Contact } |
#id ⇒ String
The unique identifier for the conversation
111 |
# File 'lib/surge_api/models/message_sent_webhook_event.rb', line 111 required :id, String |
#phone_number ⇒ SurgeAPI::Models::PhoneNumber
A phone number that can be used to send and receive messages and calls
123 |
# File 'lib/surge_api/models/message_sent_webhook_event.rb', line 123 required :phone_number, -> { SurgeAPI::PhoneNumber } |
Instance Method Details
#to_hash ⇒ {
106 |
# File 'sig/surge_api/models/message_sent_webhook_event.rbs', line 106
def to_hash: -> {
|