Class: SurgeAPI::Models::Organization::Address

Inherits:
Internal::Type::BaseModel show all
Defined in:
lib/surge_api/models/organization.rb,
sig/surge_api/models/organization.rbs

Overview

See Also:

  • SurgeAPI::Models::Organization#address

Instance Attribute Summary collapse

Instance Method Summary collapse

Methods inherited from Internal::Type::BaseModel

==, #==, #[], coerce, #deconstruct_keys, #deep_to_h, dump, fields, hash, #hash, inherited, inspect, #inspect, known_fields, optional, recursively_to_h, required, #to_h, #to_json, #to_s, to_sorbet_type, #to_yaml

Methods included from Internal::Type::Converter

#coerce, coerce, #dump, dump, #inspect, inspect, meta_info, new_coerce_state, type_info

Methods included from Internal::Util::SorbetRuntimeSupport

#const_missing, #define_sorbet_constant!, #sorbet_constant_defined?, #to_sorbet_type, to_sorbet_type

Constructor Details

#initializeObject



110
# File 'sig/surge_api/models/organization.rbs', line 110

def initialize: (

Instance Attribute Details

#countryString?

The two character ISO 3166 country code. If none is provided, the organization's country code will be used.

Parameters:

  • value (String, nil)

Returns:

  • (String, nil)


148
# File 'lib/surge_api/models/organization.rb', line 148

required :country, String, nil?: true

#line1String?

The first line of the address, typically the number and street name

Parameters:

  • value (String, nil)

Returns:

  • (String, nil)


154
# File 'lib/surge_api/models/organization.rb', line 154

required :line1, String, nil?: true

#line2String?

The second line of the address if needed, typically an apartment or suite number

Parameters:

  • value (String, nil)

Returns:

  • (String, nil)


160
# File 'lib/surge_api/models/organization.rb', line 160

required :line2, String, nil?: true

#localityString?

The city or locality

Parameters:

  • value (String, nil)

Returns:

  • (String, nil)


166
# File 'lib/surge_api/models/organization.rb', line 166

required :locality, String, nil?: true

#nameString?

The name to which any mail should be addressed. If none is provided, this will default to the organization's registered_name

Parameters:

  • value (String, nil)

Returns:

  • (String, nil)


173
# File 'lib/surge_api/models/organization.rb', line 173

required :name, String, nil?: true

#postal_codeString?

The postal code

Parameters:

  • value (String, nil)

Returns:

  • (String, nil)


179
# File 'lib/surge_api/models/organization.rb', line 179

required :postal_code, String, nil?: true

#regionString?

The state or region

Parameters:

  • value (String, nil)

Returns:

  • (String, nil)


185
# File 'lib/surge_api/models/organization.rb', line 185

required :region, String, nil?: true

Instance Method Details

#to_hash{

Returns:

  • ({)


120
# File 'sig/surge_api/models/organization.rbs', line 120

def to_hash: -> {