Class: SurgeAPI::Models::Organization::Contact

Inherits:
Internal::Type::BaseModel show all
Defined in:
lib/surge_api/models/organization.rb

Overview

See Also:

Defined Under Namespace

Modules: Title

Instance Attribute Summary collapse

Instance Method Summary collapse

Methods inherited from Internal::Type::BaseModel

==, #==, #[], coerce, #deconstruct_keys, #deep_to_h, dump, fields, hash, #hash, inherited, inspect, #inspect, known_fields, optional, recursively_to_h, required, #to_h, #to_json, #to_s, to_sorbet_type, #to_yaml

Methods included from Internal::Type::Converter

#coerce, coerce, #dump, dump, #inspect, inspect, meta_info, new_coerce_state, type_info

Methods included from Internal::Util::SorbetRuntimeSupport

#const_missing, #define_sorbet_constant!, #sorbet_constant_defined?, #to_sorbet_type, to_sorbet_type

Constructor Details

#initialize(email:, first_name:, last_name:, phone_number:, title:, title_other:) ⇒ Object

Some parameter documentations has been truncated, see SurgeAPI::Models::Organization::Contact for more details.

An object representing an individual who can be contacted if the carriers have any questions about the business.

Parameters:

  • email (String, nil)

    An email address at which the individual can be reached. Typically an email usin

  • first_name (String, nil)

    The first name (or given name) of the individual

  • last_name (String, nil)

    The last name (or family name) of the individual

  • phone_number (String, nil)

    A phone number at which the individual can be reached (E.164 format)

  • title (Symbol, SurgeAPI::Models::Organization::Contact::Title, nil)

    The job title of the individual.

  • title_other (String, nil)

    If ‘other` is provided for the `title` field, this field should be used to provi



# File 'lib/surge_api/models/organization.rb', line 251

Instance Attribute Details

#emailString?

An email address at which the individual can be reached. Typically an email using the same domain name as the website URL will be preferred (e.g. with a website domain of ‘dtprecisionauto.com`, an email like `dom@dtprecisionauto.com` will be preferred over one like `dom@anothergarage.com` or `dom.toretto@gmail.com`)

Returns:

  • (String, nil)


218
# File 'lib/surge_api/models/organization.rb', line 218

required :email, String, nil?: true

#first_nameString?

The first name (or given name) of the individual

Returns:

  • (String, nil)


224
# File 'lib/surge_api/models/organization.rb', line 224

required :first_name, String, nil?: true

#last_nameString?

The last name (or family name) of the individual

Returns:

  • (String, nil)


230
# File 'lib/surge_api/models/organization.rb', line 230

required :last_name, String, nil?: true

#phone_numberString?

A phone number at which the individual can be reached (E.164 format)

Returns:

  • (String, nil)


236
# File 'lib/surge_api/models/organization.rb', line 236

required :phone_number, String, nil?: true

#titleSymbol, ...

The job title of the individual.



242
# File 'lib/surge_api/models/organization.rb', line 242

required :title, enum: -> { SurgeAPI::Organization::Contact::Title }, nil?: true

#title_otherString?

If ‘other` is provided for the `title` field, this field should be used to provide the title of the individual

Returns:

  • (String, nil)


249
# File 'lib/surge_api/models/organization.rb', line 249

required :title_other, String, nil?: true