Module: SurgeAPI::Models::Organization::IdentifierType
- Extended by:
- Internal::Type::Enum
- Defined in:
- lib/surge_api/models/organization.rb
Overview
The type of identifier being provided for the organization. Support for more values will be added in the future.
Constant Summary collapse
- EIN =
:ein
Method Summary
Methods included from Internal::Type::Enum
==, ===, coerce, dump, hash, inspect, to_sorbet_type, values
Methods included from Internal::Util::SorbetRuntimeSupport
#const_missing, #define_sorbet_constant!, #sorbet_constant_defined?, #to_sorbet_type, to_sorbet_type
Methods included from Internal::Type::Converter
#coerce, coerce, #dump, dump, #inspect, inspect, meta_info, new_coerce_state, type_info