Class: SurgeAPI::Models::PhoneNumber
- Inherits:
-
Internal::Type::BaseModel
- Object
- Internal::Type::BaseModel
- SurgeAPI::Models::PhoneNumber
- Defined in:
- lib/surge_api/models/phone_number.rb,
sig/surge_api/models/phone_number.rbs
Overview
Defined Under Namespace
Modules: Type Classes: Campaign
Instance Attribute Summary collapse
-
#campaign ⇒ SurgeAPI::Models::PhoneNumber::Campaign?
Campaign attachment details for a domestic local phone number.
-
#campaign_id ⇒ String?
deprecated
Deprecated.
Use
campaign.idinstead. -
#id ⇒ String
Unique identifier for the phone number.
-
#name ⇒ String?
A human-readable name for the phone number.
-
#number ⇒ String
The phone number in E.164 format.
-
#type ⇒ Symbol, SurgeAPI::Models::PhoneNumber::Type
Whether the phone number is local, toll-free, or short code.
Class Method Summary collapse
Instance Method Summary collapse
-
#initialize(id:, campaign:, campaign_id:, name:, number:, type:) ⇒ Object
constructor
Some parameter documentations has been truncated, see PhoneNumber for more details.
- #to_hash ⇒ {
Methods inherited from Internal::Type::BaseModel
==, #==, #[], coerce, #deconstruct_keys, #deep_to_h, dump, fields, hash, #hash, inherited, inspect, #inspect, known_fields, optional, recursively_to_h, required, #to_h, #to_json, #to_s, to_sorbet_type, #to_yaml
Methods included from Internal::Type::Converter
#coerce, coerce, #dump, dump, #inspect, inspect, meta_info, new_coerce_state, type_info
Methods included from Internal::Util::SorbetRuntimeSupport
#const_missing, #define_sorbet_constant!, #sorbet_constant_defined?, #to_sorbet_type, to_sorbet_type
Constructor Details
#initialize(id:, campaign:, campaign_id:, name:, number:, type:) ⇒ Object
Some parameter documentations has been truncated, see SurgeAPI::Models::PhoneNumber for more details.
A phone number that can be used to send and receive messages and calls
|
|
# File 'lib/surge_api/models/phone_number.rb', line 46
|
Instance Attribute Details
#campaign ⇒ SurgeAPI::Models::PhoneNumber::Campaign?
Campaign attachment details for a domestic local phone number
17 |
# File 'lib/surge_api/models/phone_number.rb', line 17 required :campaign, -> { SurgeAPI::PhoneNumber::Campaign }, nil?: true |
#campaign_id ⇒ String?
Use campaign.id instead.
Deprecated. The unique identifier of the campaign this phone number is attached to, if any
26 |
# File 'lib/surge_api/models/phone_number.rb', line 26 required :campaign_id, String, nil?: true |
#id ⇒ String
Unique identifier for the phone number
11 |
# File 'lib/surge_api/models/phone_number.rb', line 11 required :id, String |
#name ⇒ String?
A human-readable name for the phone number
32 |
# File 'lib/surge_api/models/phone_number.rb', line 32 required :name, String, nil?: true |
#number ⇒ String
The phone number in E.164 format
38 |
# File 'lib/surge_api/models/phone_number.rb', line 38 required :number, String |
#type ⇒ Symbol, SurgeAPI::Models::PhoneNumber::Type
Whether the phone number is local, toll-free, or short code
44 |
# File 'lib/surge_api/models/phone_number.rb', line 44 required :type, enum: -> { SurgeAPI::PhoneNumber::Type } |
Class Method Details
.values ⇒ Array<Symbol>
|
|
# File 'lib/surge_api/models/phone_number.rb', line 96
|
Instance Method Details
#to_hash ⇒ {
35 |
# File 'sig/surge_api/models/phone_number.rbs', line 35
def to_hash: -> {
|