Class: SurgeAPI::Models::PhoneNumber::Campaign

Inherits:
Internal::Type::BaseModel show all
Defined in:
lib/surge_api/models/phone_number.rb,
sig/surge_api/models/phone_number.rbs

Overview

See Also:

  • SurgeAPI::Models::PhoneNumber#campaign

Defined Under Namespace

Modules: AttachmentStatus

Instance Attribute Summary collapse

Instance Method Summary collapse

Methods inherited from Internal::Type::BaseModel

==, #==, #[], coerce, #deconstruct_keys, #deep_to_h, dump, fields, hash, #hash, inherited, inspect, #inspect, known_fields, optional, recursively_to_h, required, #to_h, #to_json, #to_s, to_sorbet_type, #to_yaml

Methods included from Internal::Type::Converter

#coerce, coerce, #dump, dump, #inspect, inspect, meta_info, new_coerce_state, type_info

Methods included from Internal::Util::SorbetRuntimeSupport

#const_missing, #define_sorbet_constant!, #sorbet_constant_defined?, #to_sorbet_type, to_sorbet_type

Constructor Details

#initialize(id:, attachment_status:) ⇒ Object

Campaign attachment details for a domestic local phone number

Parameters:



# File 'lib/surge_api/models/phone_number.rb', line 78

Instance Attribute Details

#attachment_statusSymbol, SurgeAPI::Models::PhoneNumber::Campaign::AttachmentStatus

The current campaign attachment status for this phone number.

Parameters:

  • value (SurgeAPI::Models::PhoneNumber::Campaign::attachment_status)

Returns:



76
# File 'lib/surge_api/models/phone_number.rb', line 76

required :attachment_status, enum: -> { SurgeAPI::PhoneNumber::Campaign::AttachmentStatus }

#idString

The unique identifier of the campaign this phone number is attached to

Parameters:

  • value (String)

Returns:

  • (String)


70
# File 'lib/surge_api/models/phone_number.rb', line 70

required :id, String

Instance Method Details

#to_hash{

Returns:

  • ({)


60
# File 'sig/surge_api/models/phone_number.rbs', line 60

def to_hash: -> {