Class: SurgeAPI::Models::PhoneNumberAttachedToCampaignWebhookEvent::Data

Inherits:
Internal::Type::BaseModel show all
Defined in:
lib/surge_api/models/phone_number_attached_to_campaign_webhook_event.rb,
sig/surge_api/models/phone_number_attached_to_campaign_webhook_event.rbs

Overview

See Also:

  • SurgeAPI::Models::PhoneNumberAttachedToCampaignWebhookEvent#data

Defined Under Namespace

Modules: Type Classes: Campaign

Instance Attribute Summary collapse

Class Method Summary collapse

Instance Method Summary collapse

Methods inherited from Internal::Type::BaseModel

==, #==, #[], coerce, #deconstruct_keys, #deep_to_h, dump, fields, hash, #hash, inherited, inspect, #inspect, known_fields, optional, recursively_to_h, required, #to_h, #to_json, #to_s, to_sorbet_type, #to_yaml

Methods included from Internal::Type::Converter

#coerce, coerce, #dump, dump, #inspect, inspect, meta_info, new_coerce_state, type_info

Methods included from Internal::Util::SorbetRuntimeSupport

#const_missing, #define_sorbet_constant!, #sorbet_constant_defined?, #to_sorbet_type, to_sorbet_type

Constructor Details

#initialize(id:, campaign:, campaign_id:, name:, number:, type:) ⇒ Object

Some parameter documentations has been truncated, see SurgeAPI::Models::PhoneNumberAttachedToCampaignWebhookEvent::Data for more details.

The data associated with the event

Parameters:



# File 'lib/surge_api/models/phone_number_attached_to_campaign_webhook_event.rb', line 88

Instance Attribute Details

#campaignSurgeAPI::Models::PhoneNumberAttachedToCampaignWebhookEvent::Data::Campaign?

Campaign attachment details for a domestic local phone number

Parameters:

  • value (SurgeAPI::PhoneNumberAttachedToCampaignWebhookEvent::Data::Campaign, nil)

Returns:



55
56
57
58
59
# File 'lib/surge_api/models/phone_number_attached_to_campaign_webhook_event.rb', line 55

required :campaign,
-> {
  SurgeAPI::PhoneNumberAttachedToCampaignWebhookEvent::Data::Campaign
},
nil?: true

#campaign_idString

Deprecated.

Use campaign.id instead.

Deprecated. The unique identifier of the campaign this phone number is attached to

Parameters:

  • value (String)

Returns:

  • (String)


68
# File 'lib/surge_api/models/phone_number_attached_to_campaign_webhook_event.rb', line 68

required :campaign_id, String

#idString

The unique identifier for the phone number

Parameters:

  • value (String)

Returns:

  • (String)


49
# File 'lib/surge_api/models/phone_number_attached_to_campaign_webhook_event.rb', line 49

required :id, String

#nameString?

A human-readable name for the phone number

Parameters:

  • value (String, nil)

Returns:

  • (String, nil)


74
# File 'lib/surge_api/models/phone_number_attached_to_campaign_webhook_event.rb', line 74

required :name, String, nil?: true

#numberString

The phone number in E.164 format

Parameters:

  • value (String)

Returns:

  • (String)


80
# File 'lib/surge_api/models/phone_number_attached_to_campaign_webhook_event.rb', line 80

required :number, String

#typeSymbol, SurgeAPI::Models::PhoneNumberAttachedToCampaignWebhookEvent::Data::Type

Whether the phone number is local, toll-free, or short code

Parameters:

  • value (SurgeAPI::Models::PhoneNumberAttachedToCampaignWebhookEvent::Data::type_)

Returns:



86
# File 'lib/surge_api/models/phone_number_attached_to_campaign_webhook_event.rb', line 86

required :type, enum: -> { SurgeAPI::PhoneNumberAttachedToCampaignWebhookEvent::Data::Type }

Class Method Details

.valuesArray<Symbol>

Returns:

  • (Array<Symbol>)


# File 'lib/surge_api/models/phone_number_attached_to_campaign_webhook_event.rb', line 140

Instance Method Details

#to_hash{

Returns:

  • ({)


66
# File 'sig/surge_api/models/phone_number_attached_to_campaign_webhook_event.rbs', line 66

def to_hash: -> {