Class: SurgeAPI::Models::PhoneNumberAttachedToCampaignWebhookEvent::Data::Campaign

Inherits:
Internal::Type::BaseModel show all
Defined in:
lib/surge_api/models/phone_number_attached_to_campaign_webhook_event.rb,
sig/surge_api/models/phone_number_attached_to_campaign_webhook_event.rbs

Overview

See Also:

  • SurgeAPI::Models::PhoneNumberAttachedToCampaignWebhookEvent::Data#campaign

Defined Under Namespace

Modules: AttachmentStatus

Instance Attribute Summary collapse

Instance Method Summary collapse

Methods inherited from Internal::Type::BaseModel

==, #==, #[], coerce, #deconstruct_keys, #deep_to_h, dump, fields, hash, #hash, inherited, inspect, #inspect, known_fields, optional, recursively_to_h, required, #to_h, #to_json, #to_s, to_sorbet_type, #to_yaml

Methods included from Internal::Type::Converter

#coerce, coerce, #dump, dump, #inspect, inspect, meta_info, new_coerce_state, type_info

Methods included from Internal::Util::SorbetRuntimeSupport

#const_missing, #define_sorbet_constant!, #sorbet_constant_defined?, #to_sorbet_type, to_sorbet_type

Constructor Details

#initialize(id:, attachment_status:) ⇒ Object

Campaign attachment details for a domestic local phone number

Parameters:



# File 'lib/surge_api/models/phone_number_attached_to_campaign_webhook_event.rb', line 122

Instance Attribute Details

#attachment_statusSymbol, SurgeAPI::Models::PhoneNumberAttachedToCampaignWebhookEvent::Data::Campaign::AttachmentStatus

The current campaign attachment status for this phone number.

Parameters:

  • value (SurgeAPI::Models::PhoneNumberAttachedToCampaignWebhookEvent::Data::Campaign::attachment_status)

Returns:



119
120
# File 'lib/surge_api/models/phone_number_attached_to_campaign_webhook_event.rb', line 119

required :attachment_status,
enum: -> { SurgeAPI::PhoneNumberAttachedToCampaignWebhookEvent::Data::Campaign::AttachmentStatus }

#idString

The unique identifier of the campaign this phone number is attached to

Parameters:

  • value (String)

Returns:

  • (String)


113
# File 'lib/surge_api/models/phone_number_attached_to_campaign_webhook_event.rb', line 113

required :id, String

Instance Method Details

#to_hash{

Returns:

  • ({)


91
# File 'sig/surge_api/models/phone_number_attached_to_campaign_webhook_event.rbs', line 91

def to_hash: -> {