Class: SurgeAPI::Models::PhoneNumberImportedWebhookEvent::Data
- Inherits:
-
Internal::Type::BaseModel
- Object
- Internal::Type::BaseModel
- SurgeAPI::Models::PhoneNumberImportedWebhookEvent::Data
- Defined in:
- lib/surge_api/models/phone_number_imported_webhook_event.rb,
sig/surge_api/models/phone_number_imported_webhook_event.rbs
Overview
Defined Under Namespace
Modules: Type Classes: Campaign
Instance Attribute Summary collapse
-
#campaign ⇒ SurgeAPI::Models::PhoneNumberImportedWebhookEvent::Data::Campaign?
Campaign attachment details for a domestic local phone number.
-
#campaign_id ⇒ String?
deprecated
Deprecated.
Use
campaign.idinstead. -
#id ⇒ String
The unique identifier for the phone number.
-
#name ⇒ String?
A human-readable name for the phone number.
-
#number ⇒ String
The phone number in E.164 format.
-
#type ⇒ Symbol, SurgeAPI::Models::PhoneNumberImportedWebhookEvent::Data::Type
Whether the phone number is local, toll-free, or short code.
Class Method Summary collapse
Instance Method Summary collapse
-
#initialize(id:, campaign:, campaign_id:, name:, number:, type:) ⇒ Object
constructor
Some parameter documentations has been truncated, see Data for more details.
- #to_hash ⇒ {
Methods inherited from Internal::Type::BaseModel
==, #==, #[], coerce, #deconstruct_keys, #deep_to_h, dump, fields, hash, #hash, inherited, inspect, #inspect, known_fields, optional, recursively_to_h, required, #to_h, #to_json, #to_s, to_sorbet_type, #to_yaml
Methods included from Internal::Type::Converter
#coerce, coerce, #dump, dump, inspect, #inspect, meta_info, new_coerce_state, type_info
Methods included from Internal::Util::SorbetRuntimeSupport
#const_missing, #define_sorbet_constant!, #sorbet_constant_defined?, #to_sorbet_type, to_sorbet_type
Constructor Details
#initialize(id:, campaign:, campaign_id:, name:, number:, type:) ⇒ Object
Some parameter documentations has been truncated, see SurgeAPI::Models::PhoneNumberImportedWebhookEvent::Data for more details.
The data associated with the event
|
|
# File 'lib/surge_api/models/phone_number_imported_webhook_event.rb', line 80
|
Instance Attribute Details
#campaign ⇒ SurgeAPI::Models::PhoneNumberImportedWebhookEvent::Data::Campaign?
Campaign attachment details for a domestic local phone number
51 |
# File 'lib/surge_api/models/phone_number_imported_webhook_event.rb', line 51 required :campaign, -> { SurgeAPI::PhoneNumberImportedWebhookEvent::Data::Campaign }, nil?: true |
#campaign_id ⇒ String?
Use campaign.id instead.
Deprecated. The unique identifier of the campaign this phone number is attached to
60 |
# File 'lib/surge_api/models/phone_number_imported_webhook_event.rb', line 60 required :campaign_id, String, nil?: true |
#id ⇒ String
The unique identifier for the phone number
45 |
# File 'lib/surge_api/models/phone_number_imported_webhook_event.rb', line 45 required :id, String |
#name ⇒ String?
A human-readable name for the phone number
66 |
# File 'lib/surge_api/models/phone_number_imported_webhook_event.rb', line 66 required :name, String, nil?: true |
#number ⇒ String
The phone number in E.164 format
72 |
# File 'lib/surge_api/models/phone_number_imported_webhook_event.rb', line 72 required :number, String |
#type ⇒ Symbol, SurgeAPI::Models::PhoneNumberImportedWebhookEvent::Data::Type
Whether the phone number is local, toll-free, or short code
78 |
# File 'lib/surge_api/models/phone_number_imported_webhook_event.rb', line 78 required :type, enum: -> { SurgeAPI::PhoneNumberImportedWebhookEvent::Data::Type } |
Class Method Details
.values ⇒ Array<Symbol>
|
|
# File 'lib/surge_api/models/phone_number_imported_webhook_event.rb', line 131
|
Instance Method Details
#to_hash ⇒ {
66 |
# File 'sig/surge_api/models/phone_number_imported_webhook_event.rbs', line 66
def to_hash: -> {
|