Class: SurgeAPI::Models::PhoneNumberPurchaseParams
- Inherits:
-
Internal::Type::BaseModel
- Object
- Internal::Type::BaseModel
- SurgeAPI::Models::PhoneNumberPurchaseParams
- Extended by:
- Internal::Type::RequestParameters::Converter
- Includes:
- Internal::Type::RequestParameters
- Defined in:
- lib/surge_api/models/phone_number_purchase_params.rb,
sig/surge_api/models/phone_number_purchase_params.rbs
Overview
Defined Under Namespace
Modules: Type
Instance Attribute Summary collapse
-
#account_id ⇒ String
The account for which the phone number should be created.
-
#area_code ⇒ String?
The desired area code for this phone number.
-
#latitude ⇒ Float?
Latitude to search for nearby phone numbers.
-
#longitude ⇒ Float?
Longitude to search for nearby phone numbers.
-
#name ⇒ String?
A human-readable name for the phone number.
-
#type ⇒ Symbol, ...
Whether the phone number is local or toll-free.
Attributes included from Internal::Type::RequestParameters
Instance Method Summary collapse
-
#initialize(account_id:, area_code: nil, latitude: nil, longitude: nil, name: nil, type: nil, request_options: {}) ⇒ Object
constructor
Some parameter documentations has been truncated, see PhoneNumberPurchaseParams for more details.
- #to_hash ⇒ {
Methods included from Internal::Type::RequestParameters::Converter
Methods included from Internal::Type::RequestParameters
Methods inherited from Internal::Type::BaseModel
==, #==, #[], coerce, #deconstruct_keys, #deep_to_h, dump, fields, hash, #hash, inherited, inspect, #inspect, known_fields, optional, recursively_to_h, required, #to_h, #to_json, #to_s, to_sorbet_type, #to_yaml
Methods included from Internal::Type::Converter
#coerce, coerce, #dump, dump, #inspect, inspect, meta_info, new_coerce_state, type_info
Methods included from Internal::Util::SorbetRuntimeSupport
#const_missing, #define_sorbet_constant!, #sorbet_constant_defined?, #to_sorbet_type, to_sorbet_type
Constructor Details
#initialize(account_id:, area_code: nil, latitude: nil, longitude: nil, name: nil, type: nil, request_options: {}) ⇒ Object
Some parameter documentations has been truncated, see SurgeAPI::Models::PhoneNumberPurchaseParams for more details.
|
|
# File 'lib/surge_api/models/phone_number_purchase_params.rb', line 51
|
Instance Attribute Details
#account_id ⇒ String
The account for which the phone number should be created.
14 |
# File 'lib/surge_api/models/phone_number_purchase_params.rb', line 14 required :account_id, String |
#area_code ⇒ String?
The desired area code for this phone number. If provided without type, the type will be inferred.
21 |
# File 'lib/surge_api/models/phone_number_purchase_params.rb', line 21 optional :area_code, String |
#latitude ⇒ Float?
Latitude to search for nearby phone numbers. Must be used with longitude. If provided without type, type will be inferred as 'local'.
28 |
# File 'lib/surge_api/models/phone_number_purchase_params.rb', line 28 optional :latitude, Float |
#longitude ⇒ Float?
Longitude to search for nearby phone numbers. Must be used with latitude. If provided without type, type will be inferred as 'local'.
35 |
# File 'lib/surge_api/models/phone_number_purchase_params.rb', line 35 optional :longitude, Float |
#name ⇒ String?
A human-readable name for the phone number. If not provided, defaults to the formatted phone number.
42 |
# File 'lib/surge_api/models/phone_number_purchase_params.rb', line 42 optional :name, String |
#type ⇒ Symbol, ...
Whether the phone number is local or toll-free. Can be omitted if area_code or latitude/longitude are provided.
49 |
# File 'lib/surge_api/models/phone_number_purchase_params.rb', line 49 optional :type, enum: -> { SurgeAPI::PhoneNumberPurchaseParams::Type } |
Instance Method Details
#to_hash ⇒ {
52 |
# File 'sig/surge_api/models/phone_number_purchase_params.rbs', line 52
def to_hash: -> {
|