Class: SurgeAPI::Models::User

Inherits:
Internal::Type::BaseModel show all
Defined in:
lib/surge_api/models/user.rb

Overview

Instance Attribute Summary collapse

Instance Method Summary collapse

Methods inherited from Internal::Type::BaseModel

==, #==, #[], coerce, #deconstruct_keys, #deep_to_h, dump, fields, hash, #hash, inherited, inspect, #inspect, known_fields, optional, recursively_to_h, required, #to_h, #to_json, #to_s, to_sorbet_type, #to_yaml

Methods included from Internal::Type::Converter

#coerce, coerce, #dump, dump, #inspect, inspect, meta_info, new_coerce_state, type_info

Methods included from Internal::Util::SorbetRuntimeSupport

#const_missing, #define_sorbet_constant!, #sorbet_constant_defined?, #to_sorbet_type, to_sorbet_type

Constructor Details

#initialize(first_name:, id: nil, last_name: nil, metadata: nil, photo_url: nil) ⇒ Object

A user of the app

Parameters:

  • first_name (String)

    The user’s first name.

  • id (String) (defaults to: nil)

    Unique identifier for the object.

  • last_name (String) (defaults to: nil)

    The user’s last name.

  • metadata (Hash{Symbol=>String}) (defaults to: nil)

    Set of key-value pairs that will be stored with the object.

  • photo_url (String) (defaults to: nil)

    URL of a photo to be used as the user’s avatar.



# File 'lib/surge_api/models/user.rb', line 37

Instance Attribute Details

#first_nameString

The user’s first name.

Returns:

  • (String)


11
# File 'lib/surge_api/models/user.rb', line 11

required :first_name, String

#idString?

Unique identifier for the object.

Returns:

  • (String, nil)


17
# File 'lib/surge_api/models/user.rb', line 17

optional :id, String

#last_nameString?

The user’s last name.

Returns:

  • (String, nil)


23
# File 'lib/surge_api/models/user.rb', line 23

optional :last_name, String

#metadataHash{Symbol=>String}?

Set of key-value pairs that will be stored with the object.

Returns:

  • (Hash{Symbol=>String}, nil)


29
# File 'lib/surge_api/models/user.rb', line 29

optional :metadata, SurgeAPI::Internal::Type::HashOf[String]

#photo_urlString?

URL of a photo to be used as the user’s avatar.

Returns:

  • (String, nil)


35
# File 'lib/surge_api/models/user.rb', line 35

optional :photo_url, String