Class: SurgeAPI::Models::UserCreateParams

Inherits:
Internal::Type::BaseModel show all
Extended by:
Internal::Type::RequestParameters::Converter
Includes:
Internal::Type::RequestParameters
Defined in:
lib/surge_api/models/user_create_params.rb

Overview

Instance Attribute Summary collapse

Attributes included from Internal::Type::RequestParameters

#request_options

Instance Method Summary collapse

Methods included from Internal::Type::RequestParameters::Converter

dump_request

Methods included from Internal::Type::RequestParameters

included

Methods inherited from Internal::Type::BaseModel

==, #==, #[], coerce, #deconstruct_keys, #deep_to_h, dump, fields, hash, #hash, inherited, inspect, #inspect, known_fields, optional, recursively_to_h, required, #to_h, #to_json, #to_s, to_sorbet_type, #to_yaml

Methods included from Internal::Type::Converter

#coerce, coerce, #dump, dump, #inspect, inspect, meta_info, new_coerce_state, type_info

Methods included from Internal::Util::SorbetRuntimeSupport

#const_missing, #define_sorbet_constant!, #sorbet_constant_defined?, #to_sorbet_type, to_sorbet_type

Constructor Details

#initialize(first_name:, last_name: nil, metadata: nil, photo_url: nil, request_options: {}) ⇒ Object

Parameters:

  • first_name (String)

    The user’s first name.

  • last_name (String) (defaults to: nil)

    The user’s last name.

  • metadata (Hash{Symbol=>String}) (defaults to: nil)

    Set of key-value pairs that will be stored with the object.

  • photo_url (String) (defaults to: nil)

    URL of a photo to be used as the user’s avatar.

  • request_options (SurgeAPI::RequestOptions, Hash{Symbol=>Object}) (defaults to: {})


# File 'lib/surge_api/models/user_create_params.rb', line 34

Instance Attribute Details

#first_nameString

The user’s first name.

Returns:

  • (String)


14
# File 'lib/surge_api/models/user_create_params.rb', line 14

required :first_name, String

#last_nameString?

The user’s last name.

Returns:

  • (String, nil)


20
# File 'lib/surge_api/models/user_create_params.rb', line 20

optional :last_name, String

#metadataHash{Symbol=>String}?

Set of key-value pairs that will be stored with the object.

Returns:

  • (Hash{Symbol=>String}, nil)


26
# File 'lib/surge_api/models/user_create_params.rb', line 26

optional :metadata, SurgeAPI::Internal::Type::HashOf[String]

#photo_urlString?

URL of a photo to be used as the user’s avatar.

Returns:

  • (String, nil)


32
# File 'lib/surge_api/models/user_create_params.rb', line 32

optional :photo_url, String