Class: SurgeAPI::Models::UserCreateTokenParams
- Inherits:
-
Internal::Type::BaseModel
- Object
- Internal::Type::BaseModel
- SurgeAPI::Models::UserCreateTokenParams
- Extended by:
- Internal::Type::RequestParameters::Converter
- Includes:
- Internal::Type::RequestParameters
- Defined in:
- lib/surge_api/models/user_create_token_params.rb,
sig/surge_api/models/user_create_token_params.rbs
Overview
Instance Attribute Summary collapse
-
#duration_seconds ⇒ Integer?
For how many seconds the token should be accepted.
-
#user_id ⇒ String
The user for which the token represents authentication.
Attributes included from Internal::Type::RequestParameters
Instance Method Summary collapse
Methods included from Internal::Type::RequestParameters::Converter
Methods included from Internal::Type::RequestParameters
Methods inherited from Internal::Type::BaseModel
==, #==, #[], coerce, #deconstruct_keys, #deep_to_h, dump, fields, hash, #hash, inherited, inspect, #inspect, known_fields, optional, recursively_to_h, required, #to_h, #to_json, #to_s, to_sorbet_type, #to_yaml
Methods included from Internal::Type::Converter
#coerce, coerce, #dump, dump, #inspect, inspect, meta_info, new_coerce_state, type_info
Methods included from Internal::Util::SorbetRuntimeSupport
#const_missing, #define_sorbet_constant!, #sorbet_constant_defined?, #to_sorbet_type, to_sorbet_type
Constructor Details
#initialize(user_id:, duration_seconds: nil, request_options: {}) ⇒ Object
|
|
# File 'lib/surge_api/models/user_create_token_params.rb', line 22
|
Instance Attribute Details
#duration_seconds ⇒ Integer?
For how many seconds the token should be accepted. Defaults to 15 minutes.
20 |
# File 'lib/surge_api/models/user_create_token_params.rb', line 20 optional :duration_seconds, Integer |
#user_id ⇒ String
The user for which the token represents authentication.
14 |
# File 'lib/surge_api/models/user_create_token_params.rb', line 14 required :user_id, String |
Instance Method Details
#to_hash ⇒ {
23 |
# File 'sig/surge_api/models/user_create_token_params.rbs', line 23
def to_hash: -> {
|