Class: SurgeAPI::Models::Verification
- Inherits:
-
Internal::Type::BaseModel
- Object
- Internal::Type::BaseModel
- SurgeAPI::Models::Verification
- Defined in:
- lib/surge_api/models/verification.rb
Overview
Defined Under Namespace
Modules: Status
Instance Attribute Summary collapse
-
#attempt_count ⇒ Integer
The number of times the code has been attempted.
-
#id ⇒ String
Unique identifier for the object.
-
#phone_number ⇒ String
The phone number being verified.
-
#status ⇒ Symbol, SurgeAPI::Models::Verification::Status
The current status of the verification.
Instance Method Summary collapse
-
#initialize(id:, attempt_count:, phone_number:, status:) ⇒ Object
constructor
A phone number verification.
Methods inherited from Internal::Type::BaseModel
==, #==, #[], coerce, #deconstruct_keys, #deep_to_h, dump, fields, hash, #hash, inherited, inspect, #inspect, known_fields, optional, recursively_to_h, required, #to_h, #to_json, #to_s, to_sorbet_type, #to_yaml
Methods included from Internal::Type::Converter
#coerce, coerce, #dump, dump, #inspect, inspect, meta_info, new_coerce_state, type_info
Methods included from Internal::Util::SorbetRuntimeSupport
#const_missing, #define_sorbet_constant!, #sorbet_constant_defined?, #to_sorbet_type, to_sorbet_type
Constructor Details
#initialize(id:, attempt_count:, phone_number:, status:) ⇒ Object
A phone number verification
|
|
# File 'lib/surge_api/models/verification.rb', line 31
|
Instance Attribute Details
#attempt_count ⇒ Integer
The number of times the code has been attempted.
17 |
# File 'lib/surge_api/models/verification.rb', line 17 required :attempt_count, Integer |
#id ⇒ String
Unique identifier for the object.
11 |
# File 'lib/surge_api/models/verification.rb', line 11 required :id, String |
#phone_number ⇒ String
The phone number being verified. In E.164 format.
23 |
# File 'lib/surge_api/models/verification.rb', line 23 required :phone_number, String |
#status ⇒ Symbol, SurgeAPI::Models::Verification::Status
The current status of the verification.
29 |
# File 'lib/surge_api/models/verification.rb', line 29 required :status, enum: -> { SurgeAPI::Verification::Status } |