Class: SurgeAPI::Models::Account
- Inherits:
-
Internal::Type::BaseModel
- Object
- Internal::Type::BaseModel
- SurgeAPI::Models::Account
- Defined in:
- lib/surge_api/models/account.rb
Overview
Instance Attribute Summary collapse
-
#brand_name ⇒ String?
The name by which the people this account communicates with know it.
-
#id ⇒ String
The account ID.
-
#name ⇒ String
The name of the account that will be visible for your internal organizational purposes.
-
#organization ⇒ SurgeAPI::Models::Organization
The legal entity on whose behalf the account will be operated.
-
#time_zone ⇒ String?
This is the time zone in which the account is headquartered.
Instance Method Summary collapse
-
#initialize(id:, brand_name:, name:, organization:, time_zone:) ⇒ Object
constructor
Some parameter documentations has been truncated, see Account for more details.
Methods inherited from Internal::Type::BaseModel
==, #==, #[], coerce, #deconstruct_keys, #deep_to_h, dump, fields, hash, #hash, inherited, inspect, #inspect, known_fields, optional, recursively_to_h, required, #to_h, #to_json, #to_s, to_sorbet_type, #to_yaml
Methods included from Internal::Type::Converter
#coerce, coerce, #dump, dump, #inspect, inspect, meta_info, new_coerce_state, type_info
Methods included from Internal::Util::SorbetRuntimeSupport
#const_missing, #define_sorbet_constant!, #sorbet_constant_defined?, #to_sorbet_type, to_sorbet_type
Constructor Details
#initialize(id:, brand_name:, name:, organization:, time_zone:) ⇒ Object
Some parameter documentations has been truncated, see SurgeAPI::Models::Account for more details.
Response containing account information.
|
|
# File 'lib/surge_api/models/account.rb', line 43
|
Instance Attribute Details
#brand_name ⇒ String?
The name by which the people this account communicates with know it. If not provided, this will match the name field.
18 |
# File 'lib/surge_api/models/account.rb', line 18 required :brand_name, String, nil?: true |
#id ⇒ String
The account ID
11 |
# File 'lib/surge_api/models/account.rb', line 11 required :id, String |
#name ⇒ String
The name of the account that will be visible for your internal organizational purposes. This will also be the default public-facing brand name unless you also set a ‘brand_name`, but otherwise the account name will never be displayed anywhere outside of Surge HQ, and may include your ID for the account or anything else that may help you.
28 |
# File 'lib/surge_api/models/account.rb', line 28 required :name, String |
#organization ⇒ SurgeAPI::Models::Organization
The legal entity on whose behalf the account will be operated.
34 |
# File 'lib/surge_api/models/account.rb', line 34 required :organization, -> { SurgeAPI::Organization } |
#time_zone ⇒ String?
This is the time zone in which the account is headquartered. This time zone may be used for compliance with TCPA restrictions on when messages may be sent.
41 |
# File 'lib/surge_api/models/account.rb', line 41 required :time_zone, String, nil?: true |