Class: SurgeAPI::Models::AccountCreateParams
- Inherits:
-
Internal::Type::BaseModel
- Object
- Internal::Type::BaseModel
- SurgeAPI::Models::AccountCreateParams
- Extended by:
- Internal::Type::RequestParameters::Converter
- Includes:
- Internal::Type::RequestParameters
- Defined in:
- lib/surge_api/models/account_create_params.rb
Overview
Defined Under Namespace
Classes: Organization
Instance Attribute Summary collapse
-
#brand_name ⇒ String?
The name by which the people this account communicates with know it.
-
#name ⇒ String
The name of the account that will be visible for your internal organizational purposes.
-
#organization ⇒ SurgeAPI::Models::AccountCreateParams::Organization?
Parameters describing the legal entity on whose behalf the account will be operated.
-
#time_zone ⇒ String?
This is the time zone in which the account is headquartered.
Attributes included from Internal::Type::RequestParameters
Method Summary
Methods included from Internal::Type::RequestParameters::Converter
Methods included from Internal::Type::RequestParameters
Methods inherited from Internal::Type::BaseModel
==, #==, #[], coerce, #deconstruct_keys, #deep_to_h, dump, fields, hash, #hash, inherited, #initialize, inspect, #inspect, known_fields, optional, recursively_to_h, required, #to_h, #to_json, #to_s, to_sorbet_type, #to_yaml
Methods included from Internal::Type::Converter
#coerce, coerce, #dump, dump, #inspect, inspect, meta_info, new_coerce_state, type_info
Methods included from Internal::Util::SorbetRuntimeSupport
#const_missing, #define_sorbet_constant!, #sorbet_constant_defined?, #to_sorbet_type, to_sorbet_type
Constructor Details
This class inherits a constructor from SurgeAPI::Internal::Type::BaseModel
Instance Attribute Details
#brand_name ⇒ String?
The name by which the people this account communicates with know it. If not provided, this will match the name field.
25 |
# File 'lib/surge_api/models/account_create_params.rb', line 25 optional :brand_name, String, nil?: true |
#name ⇒ String
The name of the account that will be visible for your internal organizational purposes. This will also be the default public-facing brand name unless you also set a ‘brand_name`, but otherwise the account name will never be displayed anywhere outside of Surge HQ, and may include your ID for the account or anything else that may help you.
18 |
# File 'lib/surge_api/models/account_create_params.rb', line 18 required :name, String |
#organization ⇒ SurgeAPI::Models::AccountCreateParams::Organization?
Parameters describing the legal entity on whose behalf the account will be operated.
32 |
# File 'lib/surge_api/models/account_create_params.rb', line 32 optional :organization, -> { SurgeAPI::AccountCreateParams::Organization } |
#time_zone ⇒ String?
This is the time zone in which the account is headquartered. This time zone may be used for compliance with TCPA restrictions on when messages may be sent.
39 |
# File 'lib/surge_api/models/account_create_params.rb', line 39 optional :time_zone, String |