Class: SurgeAPI::Models::AccountStatus
- Inherits:
-
Internal::Type::BaseModel
- Object
- Internal::Type::BaseModel
- SurgeAPI::Models::AccountStatus
- Defined in:
- lib/surge_api/models/account_status.rb
Overview
Defined Under Namespace
Classes: Capability
Instance Attribute Summary collapse
-
#capabilities ⇒ Hash{Symbol=>SurgeAPI::Models::AccountStatus::Capability}
An object where the fields are the capabilities passed in the ‘capabilities` query param, as in `local_messaging`.
Method Summary
Methods inherited from Internal::Type::BaseModel
==, #==, #[], coerce, #deconstruct_keys, #deep_to_h, dump, fields, hash, #hash, inherited, #initialize, inspect, #inspect, known_fields, optional, recursively_to_h, required, #to_h, #to_json, #to_s, to_sorbet_type, #to_yaml
Methods included from Internal::Type::Converter
#coerce, coerce, #dump, dump, #inspect, inspect, meta_info, new_coerce_state, type_info
Methods included from Internal::Util::SorbetRuntimeSupport
#const_missing, #define_sorbet_constant!, #sorbet_constant_defined?, #to_sorbet_type, to_sorbet_type
Constructor Details
This class inherits a constructor from SurgeAPI::Internal::Type::BaseModel
Instance Attribute Details
#capabilities ⇒ Hash{Symbol=>SurgeAPI::Models::AccountStatus::Capability}
An object where the fields are the capabilities passed in the ‘capabilities` query param, as in `local_messaging`.
12 |
# File 'lib/surge_api/models/account_status.rb', line 12 required :capabilities, -> { SurgeAPI::Internal::Type::HashOf[SurgeAPI::AccountStatus::Capability] } |