Class: SurgeAPI::Models::AccountStatus::Capability::Error
- Inherits:
-
Internal::Type::BaseModel
- Object
- Internal::Type::BaseModel
- SurgeAPI::Models::AccountStatus::Capability::Error
- Defined in:
- lib/surge_api/models/account_status.rb
Instance Attribute Summary collapse
-
#field ⇒ String
A dot-delimited string representing the field that has an error, as in ‘organization.contact.phone_number`.
-
#message ⇒ String
A human-readable string explaining the error.
-
#type ⇒ String
A slug for the error type.
Instance Method Summary collapse
-
#initialize(errors:, fields_needed:, status:) ⇒ Object
constructor
Some parameter documentations has been truncated, see SurgeAPI::Models::AccountStatus::Capability for more details.
Methods inherited from Internal::Type::BaseModel
==, #==, #[], coerce, #deconstruct_keys, #deep_to_h, dump, fields, hash, #hash, inherited, inspect, #inspect, known_fields, optional, recursively_to_h, required, #to_h, #to_json, #to_s, to_sorbet_type, #to_yaml
Methods included from Internal::Type::Converter
#coerce, coerce, #dump, dump, #inspect, inspect, meta_info, new_coerce_state, type_info
Methods included from Internal::Util::SorbetRuntimeSupport
#const_missing, #define_sorbet_constant!, #sorbet_constant_defined?, #to_sorbet_type, to_sorbet_type
Constructor Details
#initialize(errors:, fields_needed:, status:) ⇒ Object
Some parameter documentations has been truncated, see SurgeAPI::Models::AccountStatus::Capability for more details.
55 56 57 58 59 60 61 62 63 64 65 66 67 68 69 70 71 72 73 74 75 76 77 78 79 80 81 82 83 84 |
# File 'lib/surge_api/models/account_status.rb', line 55 class Error < SurgeAPI::Internal::Type::BaseModel # @!attribute field # A dot-delimited string representing the field that has an error, as in # `organization.contact.phone_number`. # # @return [String] required :field, String # @!attribute message # A human-readable string explaining the error. # # @return [String] required :message, String # @!attribute type # A slug for the error type # # @return [String] required :type, String # @!method initialize(field:, message:, type:) # Some parameter documentations has been truncated, see # {SurgeAPI::Models::AccountStatus::Capability::Error} for more details. # # @param field [String] A dot-delimited string representing the field that has an error, as in `organiza # # @param message [String] A human-readable string explaining the error. # # @param type [String] A slug for the error type end |
Instance Attribute Details
#field ⇒ String
A dot-delimited string representing the field that has an error, as in ‘organization.contact.phone_number`.
61 |
# File 'lib/surge_api/models/account_status.rb', line 61 required :field, String |
#message ⇒ String
A human-readable string explaining the error.
67 |
# File 'lib/surge_api/models/account_status.rb', line 67 required :message, String |
#type ⇒ String
A slug for the error type
73 |
# File 'lib/surge_api/models/account_status.rb', line 73 required :type, String |