Class: SurgeAPI::Models::AccountUpdateParams

Inherits:
Internal::Type::BaseModel show all
Extended by:
Internal::Type::RequestParameters::Converter
Includes:
Internal::Type::RequestParameters
Defined in:
lib/surge_api/models/account_update_params.rb

Overview

Defined Under Namespace

Classes: Organization

Instance Attribute Summary collapse

Attributes included from Internal::Type::RequestParameters

#request_options

Method Summary

Methods included from Internal::Type::RequestParameters::Converter

dump_request

Methods included from Internal::Type::RequestParameters

included

Methods inherited from Internal::Type::BaseModel

==, #==, #[], coerce, #deconstruct_keys, #deep_to_h, dump, fields, hash, #hash, inherited, #initialize, inspect, #inspect, known_fields, optional, recursively_to_h, required, #to_h, #to_json, #to_s, to_sorbet_type, #to_yaml

Methods included from Internal::Type::Converter

#coerce, coerce, #dump, dump, #inspect, inspect, meta_info, new_coerce_state, type_info

Methods included from Internal::Util::SorbetRuntimeSupport

#const_missing, #define_sorbet_constant!, #sorbet_constant_defined?, #to_sorbet_type, to_sorbet_type

Constructor Details

This class inherits a constructor from SurgeAPI::Internal::Type::BaseModel

Instance Attribute Details

#brand_nameString?

The name by which the people this account communicates with know it. If not provided, this will match the name field.

Returns:

  • (String, nil)


15
# File 'lib/surge_api/models/account_update_params.rb', line 15

optional :brand_name, String

#nameString?

The name of the account that will be visible for your internal organizational purposes. This will also be the default public-facing brand name unless you also set a ‘brand_name`, but otherwise the account name will never be displayed anywhere outside of Surge HQ, and may include your ID for the account or anything else that may help you.

Returns:

  • (String, nil)


25
# File 'lib/surge_api/models/account_update_params.rb', line 25

optional :name, String

#organizationSurgeAPI::Models::AccountUpdateParams::Organization?

Parameters describing the legal entity on whose behalf the account will be operated.



32
# File 'lib/surge_api/models/account_update_params.rb', line 32

optional :organization, -> { SurgeAPI::AccountUpdateParams::Organization }

#time_zoneString?

The time zone for the account

Returns:

  • (String, nil)


38
# File 'lib/surge_api/models/account_update_params.rb', line 38

optional :time_zone, String, nil?: true