Class: SurgeAPI::Models::AccountUpdateParams::Organization::Address
- Inherits:
-
Internal::Type::BaseModel
- Object
- Internal::Type::BaseModel
- SurgeAPI::Models::AccountUpdateParams::Organization::Address
- Defined in:
- lib/surge_api/models/account_update_params.rb
Overview
Instance Attribute Summary collapse
-
#country ⇒ String?
The two character ISO 3166 country code.
-
#line1 ⇒ String?
The first line of the address, typically the number and street name.
-
#line2 ⇒ String?
The second line of the address if needed, typically an apartment or suite number.
-
#locality ⇒ String?
The city or locality.
-
#name ⇒ String?
The name to which any mail should be addressed.
-
#postal_code ⇒ String?
The postal code.
-
#region ⇒ String?
The state or region.
Method Summary
Methods inherited from Internal::Type::BaseModel
==, #==, #[], coerce, #deconstruct_keys, #deep_to_h, dump, fields, hash, #hash, inherited, #initialize, inspect, #inspect, known_fields, optional, recursively_to_h, required, #to_h, #to_json, #to_s, to_sorbet_type, #to_yaml
Methods included from Internal::Type::Converter
#coerce, coerce, #dump, dump, #inspect, inspect, meta_info, new_coerce_state, type_info
Methods included from Internal::Util::SorbetRuntimeSupport
#const_missing, #define_sorbet_constant!, #sorbet_constant_defined?, #to_sorbet_type, to_sorbet_type
Constructor Details
This class inherits a constructor from SurgeAPI::Internal::Type::BaseModel
Instance Attribute Details
#country ⇒ String?
The two character ISO 3166 country code. If none is provided, the organization’s country code will be used.
207 |
# File 'lib/surge_api/models/account_update_params.rb', line 207 optional :country, String, nil?: true |
#line1 ⇒ String?
The first line of the address, typically the number and street name
213 |
# File 'lib/surge_api/models/account_update_params.rb', line 213 optional :line1, String, nil?: true |
#line2 ⇒ String?
The second line of the address if needed, typically an apartment or suite number
219 |
# File 'lib/surge_api/models/account_update_params.rb', line 219 optional :line2, String, nil?: true |
#locality ⇒ String?
The city or locality
225 |
# File 'lib/surge_api/models/account_update_params.rb', line 225 optional :locality, String, nil?: true |
#name ⇒ String?
The name to which any mail should be addressed. If none is provided, this will default to the organization’s registered_name
232 |
# File 'lib/surge_api/models/account_update_params.rb', line 232 optional :name, String, nil?: true |
#postal_code ⇒ String?
The postal code
238 |
# File 'lib/surge_api/models/account_update_params.rb', line 238 optional :postal_code, String, nil?: true |
#region ⇒ String?
The state or region
244 |
# File 'lib/surge_api/models/account_update_params.rb', line 244 optional :region, String, nil?: true |