Class: SurgeAPI::Models::BlastCreateParams
- Inherits:
-
Internal::Type::BaseModel
- Object
- Internal::Type::BaseModel
- SurgeAPI::Models::BlastCreateParams
- Extended by:
- Internal::Type::RequestParameters::Converter
- Includes:
- Internal::Type::RequestParameters
- Defined in:
- lib/surge_api/models/blast_create_params.rb,
sig/surge_api/models/blast_create_params.rbs
Overview
Defined Under Namespace
Classes: Attachment
Instance Attribute Summary collapse
-
#account_id ⇒ String
The account for which the blast should be sent.
- #attachments ⇒ Array<SurgeAPI::Models::BlastCreateParams::Attachment>?
-
#body ⇒ String?
The message body.
-
#contacts ⇒ Array<String>?
deprecated
Deprecated.
Use
toto specify recipients instead. -
#from ⇒ String?
The phone number from which to send the blast.
-
#name ⇒ String?
Optional name for the blast.
-
#segments ⇒ Array<String>?
deprecated
Deprecated.
Use
towith audience IDs (aud_...) to specify audience recipients instead. -
#send_at ⇒ Time?
When to send the blast.
-
#to ⇒ Array<String>?
List of recipients to whom the blast should be sent.
Attributes included from Internal::Type::RequestParameters
Instance Method Summary collapse
- #initialize ⇒ Object constructor
- #to_hash ⇒ {
Methods included from Internal::Type::RequestParameters::Converter
Methods included from Internal::Type::RequestParameters
Methods inherited from Internal::Type::BaseModel
==, #==, #[], coerce, #deconstruct_keys, #deep_to_h, dump, fields, hash, #hash, inherited, inspect, #inspect, known_fields, optional, recursively_to_h, required, #to_h, #to_json, #to_s, to_sorbet_type, #to_yaml
Methods included from Internal::Type::Converter
#coerce, coerce, #dump, dump, #inspect, inspect, meta_info, new_coerce_state, type_info
Methods included from Internal::Util::SorbetRuntimeSupport
#const_missing, #define_sorbet_constant!, #sorbet_constant_defined?, #to_sorbet_type, to_sorbet_type
Constructor Details
#initialize ⇒ Object
55 |
# File 'sig/surge_api/models/blast_create_params.rbs', line 55
def initialize: (
|
Instance Attribute Details
#account_id ⇒ String
The account for which the blast should be sent.
14 |
# File 'lib/surge_api/models/blast_create_params.rb', line 14 required :account_id, String |
#attachments ⇒ Array<SurgeAPI::Models::BlastCreateParams::Attachment>?
19 |
# File 'lib/surge_api/models/blast_create_params.rb', line 19 optional :attachments, -> { SurgeAPI::Internal::Type::ArrayOf[SurgeAPI::BlastCreateParams::Attachment] } |
#body ⇒ String?
The message body.
25 |
# File 'lib/surge_api/models/blast_create_params.rb', line 25 optional :body, String, nil?: true |
#contacts ⇒ Array<String>?
Use to to specify recipients instead.
Deprecated. Use to instead.
33 |
# File 'lib/surge_api/models/blast_create_params.rb', line 33 optional :contacts, SurgeAPI::Internal::Type::ArrayOf[String] |
#from ⇒ String?
The phone number from which to send the blast. This can be either the phone number in E.164 format or a Surge phone number id. If not provided, the account's default phone number is used.
41 |
# File 'lib/surge_api/models/blast_create_params.rb', line 41 optional :from, String |
#name ⇒ String?
Optional name for the blast.
47 |
# File 'lib/surge_api/models/blast_create_params.rb', line 47 optional :name, String |
#segments ⇒ Array<String>?
Use to with audience IDs (aud_...) to specify audience recipients instead.
Deprecated. Use to with audience IDs instead.
55 |
# File 'lib/surge_api/models/blast_create_params.rb', line 55 optional :segments, SurgeAPI::Internal::Type::ArrayOf[String] |
#send_at ⇒ Time?
When to send the blast. If not provided, sends immediately.
61 |
# File 'lib/surge_api/models/blast_create_params.rb', line 61 optional :send_at, Time |
#to ⇒ Array<String>?
List of recipients to whom the blast should be sent. This can be a combination of contact IDs, audience IDs, and phone numbers.
68 |
# File 'lib/surge_api/models/blast_create_params.rb', line 68 optional :to, SurgeAPI::Internal::Type::ArrayOf[String] |
Instance Method Details
#to_hash ⇒ {
68 |
# File 'sig/surge_api/models/blast_create_params.rbs', line 68
def to_hash: -> {
|