Class: SurgeAPI::Models::BlastCreateParams

Inherits:
Internal::Type::BaseModel show all
Extended by:
Internal::Type::RequestParameters::Converter
Includes:
Internal::Type::RequestParameters
Defined in:
lib/surge_api/models/blast_create_params.rb

Overview

Defined Under Namespace

Classes: Attachment

Instance Attribute Summary collapse

Attributes included from Internal::Type::RequestParameters

#request_options

Method Summary

Methods included from Internal::Type::RequestParameters::Converter

dump_request

Methods included from Internal::Type::RequestParameters

included

Methods inherited from Internal::Type::BaseModel

==, #==, #[], coerce, #deconstruct_keys, #deep_to_h, dump, fields, hash, #hash, inherited, #initialize, inspect, #inspect, known_fields, optional, recursively_to_h, required, #to_h, #to_json, #to_s, to_sorbet_type, #to_yaml

Methods included from Internal::Type::Converter

#coerce, coerce, #dump, dump, #inspect, inspect, meta_info, new_coerce_state, type_info

Methods included from Internal::Util::SorbetRuntimeSupport

#const_missing, #define_sorbet_constant!, #sorbet_constant_defined?, #to_sorbet_type, to_sorbet_type

Constructor Details

This class inherits a constructor from SurgeAPI::Internal::Type::BaseModel

Instance Attribute Details

#attachmentsArray<SurgeAPI::Models::BlastCreateParams::Attachment>?



13
# File 'lib/surge_api/models/blast_create_params.rb', line 13

optional :attachments, -> { SurgeAPI::Internal::Type::ArrayOf[SurgeAPI::BlastCreateParams::Attachment] }

#bodyString?

The message body.

Returns:

  • (String, nil)


19
# File 'lib/surge_api/models/blast_create_params.rb', line 19

optional :body, String, nil?: true

#contactsArray<String>?

Deprecated.

Use ‘to` to specify recipients instead.

Deprecated. Use ‘to` instead.

Returns:

  • (Array<String>, nil)


27
# File 'lib/surge_api/models/blast_create_params.rb', line 27

optional :contacts, SurgeAPI::Internal::Type::ArrayOf[String]

#fromString?

The phone number from which to send the blast. This can be either the phone number in E.164 format or a Surge phone number id. If not provided, the account’s default phone number is used.

Returns:

  • (String, nil)


35
# File 'lib/surge_api/models/blast_create_params.rb', line 35

optional :from, String

#nameString?

Optional name for the blast.

Returns:

  • (String, nil)


41
# File 'lib/surge_api/models/blast_create_params.rb', line 41

optional :name, String

#segmentsArray<String>?

Deprecated.

Use ‘to` to specify recipients instead.

Deprecated. Use ‘to` instead.

Returns:

  • (Array<String>, nil)


49
# File 'lib/surge_api/models/blast_create_params.rb', line 49

optional :segments, SurgeAPI::Internal::Type::ArrayOf[String]

#send_atTime?

When to send the blast. If not provided, sends immediately.

Returns:

  • (Time, nil)


55
# File 'lib/surge_api/models/blast_create_params.rb', line 55

optional :send_at, Time

#toArray<String>?

List of recipients to whom the blast should be sent. This can be a combination of contact IDs, segment IDs, and phone numbers.

Returns:

  • (Array<String>, nil)


62
# File 'lib/surge_api/models/blast_create_params.rb', line 62

optional :to, SurgeAPI::Internal::Type::ArrayOf[String]