Module: SurgeAPI::Models::Campaign::Include
- Extended by:
- Internal::Type::Enum
- Defined in:
- lib/surge_api/models/campaign.rb
Constant Summary collapse
- LINKS =
:links- PHONE_NUMBERS =
:phone_numbers- AGE_GATED =
:age_gated- DIRECT_LENDING =
:direct_lending
Instance Method Summary collapse
-
#initialize(id:, consent_flow:, description:, includes:, message_samples:, privacy_policy_url:, use_cases:, volume:, link_sample: nil, terms_and_conditions_url: nil) ⇒ Object
Some parameter documentations has been truncated, see SurgeAPI::Models::Campaign for more details.
Methods included from Internal::Type::Enum
==, ===, coerce, dump, hash, inspect, to_sorbet_type, values
Methods included from Internal::Util::SorbetRuntimeSupport
#const_missing, #define_sorbet_constant!, #sorbet_constant_defined?, #to_sorbet_type, to_sorbet_type
Methods included from Internal::Type::Converter
#coerce, coerce, #dump, dump, #inspect, inspect, meta_info, new_coerce_state, type_info
Instance Method Details
#initialize(id:, consent_flow:, description:, includes:, message_samples:, privacy_policy_url:, use_cases:, volume:, link_sample: nil, terms_and_conditions_url: nil) ⇒ Object
Some parameter documentations has been truncated, see SurgeAPI::Models::Campaign for more details.
A campaign represents the context in which one or more of your phone numbers communicates with your contacts. Consent and opt-outs are tied to the campaign.
155 156 157 158 159 160 161 162 163 164 165 |
# File 'lib/surge_api/models/campaign.rb', line 155 module Include extend SurgeAPI::Internal::Type::Enum LINKS = :links PHONE_NUMBERS = :phone_numbers AGE_GATED = :age_gated DIRECT_LENDING = :direct_lending # @!method self.values # @return [Array<Symbol>] end |