Class: SurgeAPI::Models::Contact
- Inherits:
-
Internal::Type::BaseModel
- Object
- Internal::Type::BaseModel
- SurgeAPI::Models::Contact
- Defined in:
- lib/surge_api/models/contact.rb
Overview
Instance Attribute Summary collapse
-
#email ⇒ String?
The contact’s email address.
-
#first_name ⇒ String?
The contact’s first name.
-
#id ⇒ String
Unique identifier for the object.
-
#last_name ⇒ String?
The contact’s last name.
-
#metadata ⇒ Hash{Symbol=>String}?
Set of key-value pairs that will be stored with the object.
-
#phone_number ⇒ String
The contact’s phone number in E.164 format.
Instance Method Summary collapse
-
#initialize(id:, phone_number:, email: nil, first_name: nil, last_name: nil, metadata: nil) ⇒ Object
constructor
A contact who has consented to receive messages.
Methods inherited from Internal::Type::BaseModel
==, #==, #[], coerce, #deconstruct_keys, #deep_to_h, dump, fields, hash, #hash, inherited, inspect, #inspect, known_fields, optional, recursively_to_h, required, #to_h, #to_json, #to_s, to_sorbet_type, #to_yaml
Methods included from Internal::Type::Converter
#coerce, coerce, #dump, dump, #inspect, inspect, meta_info, new_coerce_state, type_info
Methods included from Internal::Util::SorbetRuntimeSupport
#const_missing, #define_sorbet_constant!, #sorbet_constant_defined?, #to_sorbet_type, to_sorbet_type
Constructor Details
#initialize(id:, phone_number:, email: nil, first_name: nil, last_name: nil, metadata: nil) ⇒ Object
A contact who has consented to receive messages
|
|
# File 'lib/surge_api/models/contact.rb', line 43
|
Instance Attribute Details
#email ⇒ String?
The contact’s email address.
23 |
# File 'lib/surge_api/models/contact.rb', line 23 optional :email, String |
#first_name ⇒ String?
The contact’s first name.
29 |
# File 'lib/surge_api/models/contact.rb', line 29 optional :first_name, String |
#id ⇒ String
Unique identifier for the object.
11 |
# File 'lib/surge_api/models/contact.rb', line 11 required :id, String |
#last_name ⇒ String?
The contact’s last name.
35 |
# File 'lib/surge_api/models/contact.rb', line 35 optional :last_name, String |
#metadata ⇒ Hash{Symbol=>String}?
Set of key-value pairs that will be stored with the object.
41 |
# File 'lib/surge_api/models/contact.rb', line 41 optional :metadata, SurgeAPI::Internal::Type::HashOf[String] |
#phone_number ⇒ String
The contact’s phone number in E.164 format.
17 |
# File 'lib/surge_api/models/contact.rb', line 17 required :phone_number, String |