Class: SurgeAPI::Models::LinkFollowedWebhookEvent::Data
- Inherits:
-
Internal::Type::BaseModel
- Object
- Internal::Type::BaseModel
- SurgeAPI::Models::LinkFollowedWebhookEvent::Data
- Defined in:
- lib/surge_api/models/link_followed_webhook_event.rb
Overview
Instance Attribute Summary collapse
-
#id ⇒ String
The unique identifier for the link.
-
#message_id ⇒ String
The unique identifier for the message that contained the link.
-
#url ⇒ String
The original URL that was shortened.
Instance Method Summary collapse
-
#initialize(id:, message_id:, url:) ⇒ Object
constructor
The data associated with the event.
Methods inherited from Internal::Type::BaseModel
==, #==, #[], coerce, #deconstruct_keys, #deep_to_h, dump, fields, hash, #hash, inherited, inspect, #inspect, known_fields, optional, recursively_to_h, required, #to_h, #to_json, #to_s, to_sorbet_type, #to_yaml
Methods included from Internal::Type::Converter
#coerce, coerce, #dump, dump, #inspect, inspect, meta_info, new_coerce_state, type_info
Methods included from Internal::Util::SorbetRuntimeSupport
#const_missing, #define_sorbet_constant!, #sorbet_constant_defined?, #to_sorbet_type, to_sorbet_type
Constructor Details
#initialize(id:, message_id:, url:) ⇒ Object
The data associated with the event
|
|
# File 'lib/surge_api/models/link_followed_webhook_event.rb', line 59
|
Instance Attribute Details
#id ⇒ String
The unique identifier for the link
45 |
# File 'lib/surge_api/models/link_followed_webhook_event.rb', line 45 required :id, String |
#message_id ⇒ String
The unique identifier for the message that contained the link
51 |
# File 'lib/surge_api/models/link_followed_webhook_event.rb', line 51 required :message_id, String |
#url ⇒ String
The original URL that was shortened
57 |
# File 'lib/surge_api/models/link_followed_webhook_event.rb', line 57 required :url, String |