Class: SurgeAPI::Models::Message
- Inherits:
-
Internal::Type::BaseModel
- Object
- Internal::Type::BaseModel
- SurgeAPI::Models::Message
- Defined in:
- lib/surge_api/models/message.rb
Overview
Defined Under Namespace
Classes: Attachment, Conversation
Instance Attribute Summary collapse
- #attachments ⇒ Array<SurgeAPI::Models::Message::Attachment>?
-
#blast_id ⇒ String?
The ID of the blast this message belongs to, if any.
-
#body ⇒ String?
The message body.
-
#conversation ⇒ SurgeAPI::Models::Message::Conversation?
A conversation with a Contact.
-
#id ⇒ String?
Unique identifier for the object.
-
#metadata ⇒ Hash{Symbol=>String}?
Set of key-value pairs that will be stored with the object.
Instance Method Summary collapse
-
#initialize(id: nil, type: nil, url: nil) ⇒ Object
constructor
An Attachment is a file that can be sent with a message.
Methods inherited from Internal::Type::BaseModel
==, #==, #[], coerce, #deconstruct_keys, #deep_to_h, dump, fields, hash, #hash, inherited, inspect, #inspect, known_fields, optional, recursively_to_h, required, #to_h, #to_json, #to_s, to_sorbet_type, #to_yaml
Methods included from Internal::Type::Converter
#coerce, coerce, #dump, dump, #inspect, inspect, meta_info, new_coerce_state, type_info
Methods included from Internal::Util::SorbetRuntimeSupport
#const_missing, #define_sorbet_constant!, #sorbet_constant_defined?, #to_sorbet_type, to_sorbet_type
Constructor Details
#initialize(id: nil, type: nil, url: nil) ⇒ Object
An Attachment is a file that can be sent with a message.
|
|
# File 'lib/surge_api/models/message.rb', line 80
|
Instance Attribute Details
#attachments ⇒ Array<SurgeAPI::Models::Message::Attachment>?
16 |
# File 'lib/surge_api/models/message.rb', line 16 optional :attachments, -> { SurgeAPI::Internal::Type::ArrayOf[SurgeAPI::Message::Attachment] } |
#blast_id ⇒ String?
The ID of the blast this message belongs to, if any. This can be used to attribute messages back to a specific blast.
23 |
# File 'lib/surge_api/models/message.rb', line 23 optional :blast_id, String |
#body ⇒ String?
The message body.
29 |
# File 'lib/surge_api/models/message.rb', line 29 optional :body, String, nil?: true |
#conversation ⇒ SurgeAPI::Models::Message::Conversation?
A conversation with a Contact
35 |
# File 'lib/surge_api/models/message.rb', line 35 optional :conversation, -> { SurgeAPI::Message::Conversation } |
#id ⇒ String?
Unique identifier for the object.
11 |
# File 'lib/surge_api/models/message.rb', line 11 optional :id, String |