Class: SurgeAPI::Models::MessageFailedWebhookEvent::Data
- Inherits:
-
Internal::Type::BaseModel
- Object
- Internal::Type::BaseModel
- SurgeAPI::Models::MessageFailedWebhookEvent::Data
- Defined in:
- lib/surge_api/models/message_failed_webhook_event.rb
Overview
Defined Under Namespace
Classes: Attachment, Conversation
Instance Attribute Summary collapse
-
#attachments ⇒ Array<SurgeAPI::Models::MessageFailedWebhookEvent::Data::Attachment>?
Attachments included with the message.
-
#blast_id ⇒ String?
The ID of the blast this message belongs to, if any.
-
#body ⇒ String?
The content of the message.
-
#conversation ⇒ SurgeAPI::Models::MessageFailedWebhookEvent::Data::Conversation
The conversation this message belongs to.
-
#failed_at ⇒ Time
When the message failed.
-
#failure_reason ⇒ String
The reason the message failed to be delivered.
-
#id ⇒ String
The unique identifier for the message.
Instance Method Summary collapse
-
#initialize(id:, contact:, phone_number:) ⇒ Object
constructor
The conversation this message belongs to.
Methods inherited from Internal::Type::BaseModel
==, #==, #[], coerce, #deconstruct_keys, #deep_to_h, dump, fields, hash, #hash, inherited, inspect, #inspect, known_fields, optional, recursively_to_h, required, #to_h, #to_json, #to_s, to_sorbet_type, #to_yaml
Methods included from Internal::Type::Converter
#coerce, coerce, #dump, dump, #inspect, inspect, meta_info, new_coerce_state, type_info
Methods included from Internal::Util::SorbetRuntimeSupport
#const_missing, #define_sorbet_constant!, #sorbet_constant_defined?, #to_sorbet_type, to_sorbet_type
Constructor Details
#initialize(id:, contact:, phone_number:) ⇒ Object
The conversation this message belongs to
|
|
# File 'lib/surge_api/models/message_failed_webhook_event.rb', line 85
|
Instance Attribute Details
#attachments ⇒ Array<SurgeAPI::Models::MessageFailedWebhookEvent::Data::Attachment>?
Attachments included with the message
75 76 |
# File 'lib/surge_api/models/message_failed_webhook_event.rb', line 75 optional :attachments, -> { SurgeAPI::Internal::Type::ArrayOf[SurgeAPI::MessageFailedWebhookEvent::Data::Attachment] } |
#blast_id ⇒ String?
The ID of the blast this message belongs to, if any. This can be used to attribute messages back to a specific blast.
83 |
# File 'lib/surge_api/models/message_failed_webhook_event.rb', line 83 optional :blast_id, String |
#body ⇒ String?
The content of the message
51 |
# File 'lib/surge_api/models/message_failed_webhook_event.rb', line 51 required :body, String, nil?: true |
#conversation ⇒ SurgeAPI::Models::MessageFailedWebhookEvent::Data::Conversation
The conversation this message belongs to
57 |
# File 'lib/surge_api/models/message_failed_webhook_event.rb', line 57 required :conversation, -> { SurgeAPI::MessageFailedWebhookEvent::Data::Conversation } |
#failed_at ⇒ Time
When the message failed
63 |
# File 'lib/surge_api/models/message_failed_webhook_event.rb', line 63 required :failed_at, Time |
#failure_reason ⇒ String
The reason the message failed to be delivered
69 |
# File 'lib/surge_api/models/message_failed_webhook_event.rb', line 69 required :failure_reason, String |
#id ⇒ String
The unique identifier for the message
45 |
# File 'lib/surge_api/models/message_failed_webhook_event.rb', line 45 required :id, String |