Class: SurgeAPI::Models::MessageParams::MessageParamsWithConversation
- Inherits:
-
Internal::Type::BaseModel
- Object
- Internal::Type::BaseModel
- SurgeAPI::Models::MessageParams::MessageParamsWithConversation
- Defined in:
- lib/surge_api/models/message_params.rb
Defined Under Namespace
Classes: Attachment, Conversation
Instance Attribute Summary collapse
- #attachments ⇒ Array<SurgeAPI::Models::MessageParams::MessageParamsWithConversation::Attachment>?
-
#body ⇒ String?
The message body.
-
#conversation ⇒ SurgeAPI::Models::MessageParams::MessageParamsWithConversation::Conversation
Params for selecting or creating a new conversation.
-
#metadata ⇒ Hash{Symbol=>String}?
Set of key-value pairs that will be stored with the object.
-
#send_at ⇒ Time?
An optional datetime for scheduling message up to a couple of months in the future.
Instance Method Summary collapse
-
#initialize(phone_number:, email: nil, first_name: nil, last_name: nil, metadata: nil) ⇒ Object
constructor
Parameters for creating a contact.
Methods inherited from Internal::Type::BaseModel
==, #==, #[], coerce, #deconstruct_keys, #deep_to_h, dump, fields, hash, #hash, inherited, inspect, #inspect, known_fields, optional, recursively_to_h, required, #to_h, #to_json, #to_s, to_sorbet_type, #to_yaml
Methods included from Internal::Type::Converter
#coerce, coerce, #dump, dump, #inspect, inspect, meta_info, new_coerce_state, type_info
Methods included from Internal::Util::SorbetRuntimeSupport
#const_missing, #define_sorbet_constant!, #sorbet_constant_defined?, #to_sorbet_type, to_sorbet_type
Constructor Details
#initialize(phone_number:, email: nil, first_name: nil, last_name: nil, metadata: nil) ⇒ Object
Parameters for creating a contact
|
|
# File 'lib/surge_api/models/message_params.rb', line 50
|
Instance Attribute Details
#attachments ⇒ Array<SurgeAPI::Models::MessageParams::MessageParamsWithConversation::Attachment>?
28 29 |
# File 'lib/surge_api/models/message_params.rb', line 28 optional :attachments, -> { SurgeAPI::Internal::Type::ArrayOf[SurgeAPI::MessageParams::MessageParamsWithConversation::Attachment] } |
#body ⇒ String?
The message body.
35 |
# File 'lib/surge_api/models/message_params.rb', line 35 optional :body, String |
#conversation ⇒ SurgeAPI::Models::MessageParams::MessageParamsWithConversation::Conversation
Params for selecting or creating a new conversation. Either the id or the Contact must be given.
23 |
# File 'lib/surge_api/models/message_params.rb', line 23 required :conversation, -> { SurgeAPI::MessageParams::MessageParamsWithConversation::Conversation } |
#metadata ⇒ Hash{Symbol=>String}?
Set of key-value pairs that will be stored with the object.
41 |
# File 'lib/surge_api/models/message_params.rb', line 41 optional :metadata, SurgeAPI::Internal::Type::HashOf[String] |
#send_at ⇒ Time?
An optional datetime for scheduling message up to a couple of months in the future.
48 |
# File 'lib/surge_api/models/message_params.rb', line 48 optional :send_at, Time |