Class: SurgeAPI::Models::MessageParams::MessageParamsWithConversation::Conversation::Contact
- Inherits:
-
Internal::Type::BaseModel
- Object
- Internal::Type::BaseModel
- SurgeAPI::Models::MessageParams::MessageParamsWithConversation::Conversation::Contact
- Defined in:
- lib/surge_api/models/message_params.rb
Overview
Instance Attribute Summary collapse
-
#email ⇒ String?
The contact’s email address.
-
#first_name ⇒ String?
The contact’s first name.
-
#last_name ⇒ String?
The contact’s last name.
-
#metadata ⇒ Hash{Symbol=>String}?
Set of key-value pairs that will be stored with the object.
-
#phone_number ⇒ String
The contact’s phone number in E.164 format.
Method Summary
Methods inherited from Internal::Type::BaseModel
==, #==, #[], coerce, #deconstruct_keys, #deep_to_h, dump, fields, hash, #hash, inherited, #initialize, inspect, #inspect, known_fields, optional, recursively_to_h, required, #to_h, #to_json, #to_s, to_sorbet_type, #to_yaml
Methods included from Internal::Type::Converter
#coerce, coerce, #dump, dump, #inspect, inspect, meta_info, new_coerce_state, type_info
Methods included from Internal::Util::SorbetRuntimeSupport
#const_missing, #define_sorbet_constant!, #sorbet_constant_defined?, #to_sorbet_type, to_sorbet_type
Constructor Details
This class inherits a constructor from SurgeAPI::Internal::Type::BaseModel
Instance Attribute Details
#email ⇒ String?
The contact’s email address.
107 |
# File 'lib/surge_api/models/message_params.rb', line 107 optional :email, String |
#first_name ⇒ String?
The contact’s first name.
113 |
# File 'lib/surge_api/models/message_params.rb', line 113 optional :first_name, String |
#last_name ⇒ String?
The contact’s last name.
119 |
# File 'lib/surge_api/models/message_params.rb', line 119 optional :last_name, String |
#metadata ⇒ Hash{Symbol=>String}?
Set of key-value pairs that will be stored with the object.
125 |
# File 'lib/surge_api/models/message_params.rb', line 125 optional :metadata, SurgeAPI::Internal::Type::HashOf[String] |
#phone_number ⇒ String
The contact’s phone number in E.164 format.
101 |
# File 'lib/surge_api/models/message_params.rb', line 101 required :phone_number, String |