Class: SurgeAPI::Models::MessageParams::SimpleMessageParams
- Inherits:
-
Internal::Type::BaseModel
- Object
- Internal::Type::BaseModel
- SurgeAPI::Models::MessageParams::SimpleMessageParams
- Defined in:
- lib/surge_api/models/message_params.rb,
sig/surge_api/models/message_params.rbs
Defined Under Namespace
Classes: Attachment, Settings
Instance Attribute Summary collapse
- #attachments ⇒ Array<SurgeAPI::Models::MessageParams::SimpleMessageParams::Attachment>?
-
#body ⇒ String?
The message body.
-
#from ⇒ String?
The sender's phone number in E.164 format or phone number ID.
-
#metadata ⇒ Hash{Symbol=>String}?
Set of key-value pairs that will be stored with the object.
-
#send_at ⇒ Time?
An optional datetime for scheduling message up to a couple of months in the future.
-
#settings ⇒ SurgeAPI::Models::MessageParams::SimpleMessageParams::Settings?
Per-message setting overrides.
-
#to ⇒ String
The recipient's phone number in E.164 format.
Instance Method Summary collapse
-
#initialize(url:) ⇒ Object
constructor
Params for creating an attachment.
- #to_hash ⇒ {
Methods inherited from Internal::Type::BaseModel
==, #==, #[], coerce, #deconstruct_keys, #deep_to_h, dump, fields, hash, #hash, inherited, inspect, #inspect, known_fields, optional, recursively_to_h, required, #to_h, #to_json, #to_s, to_sorbet_type, #to_yaml
Methods included from Internal::Type::Converter
#coerce, coerce, #dump, dump, #inspect, inspect, meta_info, new_coerce_state, type_info
Methods included from Internal::Util::SorbetRuntimeSupport
#const_missing, #define_sorbet_constant!, #sorbet_constant_defined?, #to_sorbet_type, to_sorbet_type
Constructor Details
#initialize(url:) ⇒ Object
Params for creating an attachment
|
|
# File 'lib/surge_api/models/message_params.rb', line 265
|
Instance Attribute Details
#attachments ⇒ Array<SurgeAPI::Models::MessageParams::SimpleMessageParams::Attachment>?
203 204 |
# File 'lib/surge_api/models/message_params.rb', line 203 optional :attachments, -> { SurgeAPI::Internal::Type::ArrayOf[SurgeAPI::MessageParams::SimpleMessageParams::Attachment] } |
#body ⇒ String?
The message body.
210 |
# File 'lib/surge_api/models/message_params.rb', line 210 optional :body, String |
#from ⇒ String?
The sender's phone number in E.164 format or phone number ID. If omitted, uses the account's default phone number. Cannot be used together with 'conversation'.
217 |
# File 'lib/surge_api/models/message_params.rb', line 217 optional :from, String |
#metadata ⇒ Hash{Symbol=>String}?
Set of key-value pairs that will be stored with the object.
223 |
# File 'lib/surge_api/models/message_params.rb', line 223 optional :metadata, SurgeAPI::Internal::Type::HashOf[String] |
#send_at ⇒ Time?
An optional datetime for scheduling message up to a couple of months in the future.
230 |
# File 'lib/surge_api/models/message_params.rb', line 230 optional :send_at, Time |
#settings ⇒ SurgeAPI::Models::MessageParams::SimpleMessageParams::Settings?
Per-message setting overrides.
236 |
# File 'lib/surge_api/models/message_params.rb', line 236 optional :settings, -> { SurgeAPI::MessageParams::SimpleMessageParams::Settings } |
#to ⇒ String
The recipient's phone number in E.164 format. Cannot be used together with 'conversation'.
198 |
# File 'lib/surge_api/models/message_params.rb', line 198 required :to, String |
Instance Method Details
#to_hash ⇒ {
229 |
# File 'sig/surge_api/models/message_params.rbs', line 229
def to_hash: -> {
|