Class: SurgeAPI::Models::MessageParams::SimpleMessageParams

Inherits:
Internal::Type::BaseModel show all
Defined in:
lib/surge_api/models/message_params.rb

Defined Under Namespace

Classes: Attachment

Instance Attribute Summary collapse

Method Summary

Methods inherited from Internal::Type::BaseModel

==, #==, #[], coerce, #deconstruct_keys, #deep_to_h, dump, fields, hash, #hash, inherited, #initialize, inspect, #inspect, known_fields, optional, recursively_to_h, required, #to_h, #to_json, #to_s, to_sorbet_type, #to_yaml

Methods included from Internal::Type::Converter

#coerce, coerce, #dump, dump, #inspect, inspect, meta_info, new_coerce_state, type_info

Methods included from Internal::Util::SorbetRuntimeSupport

#const_missing, #define_sorbet_constant!, #sorbet_constant_defined?, #to_sorbet_type, to_sorbet_type

Constructor Details

This class inherits a constructor from SurgeAPI::Internal::Type::BaseModel

Instance Attribute Details

#attachmentsArray<SurgeAPI::Models::MessageParams::SimpleMessageParams::Attachment>?



167
168
# File 'lib/surge_api/models/message_params.rb', line 167

optional :attachments,
-> { SurgeAPI::Internal::Type::ArrayOf[SurgeAPI::MessageParams::SimpleMessageParams::Attachment] }

#bodyString?

The message body.

Returns:

  • (String, nil)


174
# File 'lib/surge_api/models/message_params.rb', line 174

optional :body, String

#fromString?

The sender’s phone number in E.164 format or phone number ID. If omitted, uses the account’s default phone number. Cannot be used together with ‘conversation’.

Returns:

  • (String, nil)


181
# File 'lib/surge_api/models/message_params.rb', line 181

optional :from, String

#metadataHash{Symbol=>String}?

Set of key-value pairs that will be stored with the object.

Returns:

  • (Hash{Symbol=>String}, nil)


187
# File 'lib/surge_api/models/message_params.rb', line 187

optional :metadata, SurgeAPI::Internal::Type::HashOf[String]

#send_atTime?

An optional datetime for scheduling message up to a couple of months in the future.

Returns:

  • (Time, nil)


194
# File 'lib/surge_api/models/message_params.rb', line 194

optional :send_at, Time

#toString

The recipient’s phone number in E.164 format. Cannot be used together with ‘conversation’.

Returns:

  • (String)


162
# File 'lib/surge_api/models/message_params.rb', line 162

required :to, String