Class: SurgeAPI::Models::MessageParams::SimpleMessageParams
- Inherits:
-
Internal::Type::BaseModel
- Object
- Internal::Type::BaseModel
- SurgeAPI::Models::MessageParams::SimpleMessageParams
- Defined in:
- lib/surge_api/models/message_params.rb
Defined Under Namespace
Classes: Attachment
Instance Attribute Summary collapse
- #attachments ⇒ Array<SurgeAPI::Models::MessageParams::SimpleMessageParams::Attachment>?
-
#body ⇒ String?
The message body.
-
#from ⇒ String?
The sender’s phone number in E.164 format or phone number ID.
-
#metadata ⇒ Hash{Symbol=>String}?
Set of key-value pairs that will be stored with the object.
-
#send_at ⇒ Time?
An optional datetime for scheduling message up to a couple of months in the future.
-
#to ⇒ String
The recipient’s phone number in E.164 format.
Method Summary
Methods inherited from Internal::Type::BaseModel
==, #==, #[], coerce, #deconstruct_keys, #deep_to_h, dump, fields, hash, #hash, inherited, #initialize, inspect, #inspect, known_fields, optional, recursively_to_h, required, #to_h, #to_json, #to_s, to_sorbet_type, #to_yaml
Methods included from Internal::Type::Converter
#coerce, coerce, #dump, dump, #inspect, inspect, meta_info, new_coerce_state, type_info
Methods included from Internal::Util::SorbetRuntimeSupport
#const_missing, #define_sorbet_constant!, #sorbet_constant_defined?, #to_sorbet_type, to_sorbet_type
Constructor Details
This class inherits a constructor from SurgeAPI::Internal::Type::BaseModel
Instance Attribute Details
#attachments ⇒ Array<SurgeAPI::Models::MessageParams::SimpleMessageParams::Attachment>?
167 168 |
# File 'lib/surge_api/models/message_params.rb', line 167 optional :attachments, -> { SurgeAPI::Internal::Type::ArrayOf[SurgeAPI::MessageParams::SimpleMessageParams::Attachment] } |
#body ⇒ String?
The message body.
174 |
# File 'lib/surge_api/models/message_params.rb', line 174 optional :body, String |
#from ⇒ String?
The sender’s phone number in E.164 format or phone number ID. If omitted, uses the account’s default phone number. Cannot be used together with ‘conversation’.
181 |
# File 'lib/surge_api/models/message_params.rb', line 181 optional :from, String |
#metadata ⇒ Hash{Symbol=>String}?
Set of key-value pairs that will be stored with the object.
187 |
# File 'lib/surge_api/models/message_params.rb', line 187 optional :metadata, SurgeAPI::Internal::Type::HashOf[String] |
#send_at ⇒ Time?
An optional datetime for scheduling message up to a couple of months in the future.
194 |
# File 'lib/surge_api/models/message_params.rb', line 194 optional :send_at, Time |
#to ⇒ String
The recipient’s phone number in E.164 format. Cannot be used together with ‘conversation’.
162 |
# File 'lib/surge_api/models/message_params.rb', line 162 required :to, String |