Class: SurgeAPI::Models::Organization
- Inherits:
-
Internal::Type::BaseModel
- Object
- Internal::Type::BaseModel
- SurgeAPI::Models::Organization
- Defined in:
- lib/surge_api/models/organization.rb
Defined Under Namespace
Modules: IdentifierType, Industry, RegionsOfOperation, StockExchange, Type Classes: Address, Contact
Instance Attribute Summary collapse
-
#address ⇒ SurgeAPI::Models::Organization::Address
The address of the organization’s headquarters.
-
#contact ⇒ SurgeAPI::Models::Organization::Contact
An object representing an individual who can be contacted if the carriers have any questions about the business.
-
#country ⇒ String?
The two character ISO 3166 country code for the country in which the organization is headquartered.
-
#email ⇒ String?
For publicly traded companies, an email for a representative of the company to whom a verification email will be sent.
-
#identifier ⇒ String?
The value of the identifier whose type is specified in the identifier_type field.
-
#identifier_type ⇒ Symbol, ...
The type of identifier being provided for the organization.
-
#industry ⇒ Symbol, ...
The industry in which the organization operates.
-
#mobile_number ⇒ String?
For sole proprietors, this must be a valid US mobile phone number to which a verification text message will be sent.
-
#regions_of_operation ⇒ Array<Symbol, SurgeAPI::Models::Organization::RegionsOfOperation>?
An array of regions in which the organization operates.
-
#registered_name ⇒ String?
The legal name of the organization as registered with the IRS or other relevant authorities.
-
#stock_exchange ⇒ Symbol, ...
For publicly traded companies, this is the exchange on which the company’s stock is traded.
-
#stock_symbol ⇒ String?
For publicly traded companies, the ticker symbol for the company’s stock.
-
#type ⇒ Symbol, ...
The type of organization.
-
#website ⇒ String?
The URL of the website for this organization.
Class Method Summary collapse
Instance Method Summary collapse
-
#initialize(country:, line1:, line2:, locality:, name:, postal_code:, region:) ⇒ Object
constructor
Some parameter documentations has been truncated, see Address for more details.
Methods inherited from Internal::Type::BaseModel
==, #==, #[], coerce, #deconstruct_keys, #deep_to_h, dump, fields, hash, #hash, inherited, inspect, #inspect, known_fields, optional, recursively_to_h, required, #to_h, #to_json, #to_s, to_sorbet_type, #to_yaml
Methods included from Internal::Type::Converter
#coerce, coerce, #dump, dump, #inspect, inspect, meta_info, new_coerce_state, type_info
Methods included from Internal::Util::SorbetRuntimeSupport
#const_missing, #define_sorbet_constant!, #sorbet_constant_defined?, #to_sorbet_type, to_sorbet_type
Constructor Details
#initialize(country:, line1:, line2:, locality:, name:, postal_code:, region:) ⇒ Object
Some parameter documentations has been truncated, see Address for more details.
The address of the organization’s headquarters.
|
|
# File 'lib/surge_api/models/organization.rb', line 107
|
Instance Attribute Details
#address ⇒ SurgeAPI::Models::Organization::Address
The address of the organization’s headquarters.
10 |
# File 'lib/surge_api/models/organization.rb', line 10 required :address, -> { SurgeAPI::Organization::Address } |
#contact ⇒ SurgeAPI::Models::Organization::Contact
An object representing an individual who can be contacted if the carriers have any questions about the business.
17 |
# File 'lib/surge_api/models/organization.rb', line 17 required :contact, -> { SurgeAPI::Organization::Contact } |
#country ⇒ String?
The two character ISO 3166 country code for the country in which the organization is headquartered.
24 |
# File 'lib/surge_api/models/organization.rb', line 24 required :country, String, nil?: true |
#email ⇒ String?
For publicly traded companies, an email for a representative of the company to whom a verification email will be sent. This must be an email on the same domain as the company’s website (e.g. with a website domain of ‘dtprecisionauto.com`, the email must use the same `@dtprecisionauto.com`)
34 |
# File 'lib/surge_api/models/organization.rb', line 34 required :email, String, nil?: true |
#identifier ⇒ String?
The value of the identifier whose type is specified in the identifier_type field. Typically this will be an EIN, and can be formatted with or without the hyphen.
42 |
# File 'lib/surge_api/models/organization.rb', line 42 required :identifier, String, nil?: true |
#identifier_type ⇒ Symbol, ...
The type of identifier being provided for the organization. Support for more values will be added in the future.
49 |
# File 'lib/surge_api/models/organization.rb', line 49 required :identifier_type, enum: -> { SurgeAPI::Organization::IdentifierType }, nil?: true |
#industry ⇒ Symbol, ...
The industry in which the organization operates.
55 |
# File 'lib/surge_api/models/organization.rb', line 55 required :industry, enum: -> { SurgeAPI::Organization::Industry }, nil?: true |
#mobile_number ⇒ String?
For sole proprietors, this must be a valid US mobile phone number to which a verification text message will be sent. (E.164 format)
62 |
# File 'lib/surge_api/models/organization.rb', line 62 required :mobile_number, String, nil?: true |
#regions_of_operation ⇒ Array<Symbol, SurgeAPI::Models::Organization::RegionsOfOperation>?
An array of regions in which the organization operates.
68 69 70 |
# File 'lib/surge_api/models/organization.rb', line 68 required :regions_of_operation, -> { SurgeAPI::Internal::Type::ArrayOf[enum: SurgeAPI::Organization::RegionsOfOperation] }, nil?: true |
#registered_name ⇒ String?
The legal name of the organization as registered with the IRS or other relevant authorities. For some applications, this will be matched against government records and should include all punctuation and everything else as well.
78 |
# File 'lib/surge_api/models/organization.rb', line 78 required :registered_name, String, nil?: true |
#stock_exchange ⇒ Symbol, ...
For publicly traded companies, this is the exchange on which the company’s stock is traded.
85 |
# File 'lib/surge_api/models/organization.rb', line 85 required :stock_exchange, enum: -> { SurgeAPI::Organization::StockExchange }, nil?: true |
#stock_symbol ⇒ String?
For publicly traded companies, the ticker symbol for the company’s stock
91 |
# File 'lib/surge_api/models/organization.rb', line 91 required :stock_symbol, String, nil?: true |
#type ⇒ Symbol, ...
The type of organization
97 |
# File 'lib/surge_api/models/organization.rb', line 97 required :type, enum: -> { SurgeAPI::Organization::Type }, nil?: true |
#website ⇒ String?
The URL of the website for this organization. The website should be publicly available, clearly reflect the organization’s purpose, and the URL should start with ‘https://`
105 |
# File 'lib/surge_api/models/organization.rb', line 105 required :website, String, nil?: true |
Class Method Details
.values ⇒ Array<Symbol>
|
|
# File 'lib/surge_api/models/organization.rb', line 284
|