Class: SurgeAPI::Models::Organization::Contact
- Inherits:
-
Internal::Type::BaseModel
- Object
- Internal::Type::BaseModel
- SurgeAPI::Models::Organization::Contact
- Defined in:
- lib/surge_api/models/organization.rb
Overview
Defined Under Namespace
Modules: Title
Instance Attribute Summary collapse
-
#email ⇒ String?
An email address at which the individual can be reached.
-
#first_name ⇒ String?
The first name (or given name) of the individual.
-
#last_name ⇒ String?
The last name (or family name) of the individual.
-
#phone_number ⇒ String?
A phone number at which the individual can be reached (E.164 format).
-
#title ⇒ Symbol, ...
The job title of the individual.
-
#title_other ⇒ String?
If ‘other` is provided for the `title` field, this field should be used to provide the title of the individual.
Instance Method Summary collapse
-
#initialize(email:, first_name:, last_name:, phone_number:, title:, title_other:) ⇒ Object
constructor
Some parameter documentations has been truncated, see Contact for more details.
Methods inherited from Internal::Type::BaseModel
==, #==, #[], coerce, #deconstruct_keys, #deep_to_h, dump, fields, hash, #hash, inherited, inspect, #inspect, known_fields, optional, recursively_to_h, required, #to_h, #to_json, #to_s, to_sorbet_type, #to_yaml
Methods included from Internal::Type::Converter
#coerce, coerce, #dump, dump, #inspect, inspect, meta_info, new_coerce_state, type_info
Methods included from Internal::Util::SorbetRuntimeSupport
#const_missing, #define_sorbet_constant!, #sorbet_constant_defined?, #to_sorbet_type, to_sorbet_type
Constructor Details
#initialize(email:, first_name:, last_name:, phone_number:, title:, title_other:) ⇒ Object
Some parameter documentations has been truncated, see SurgeAPI::Models::Organization::Contact for more details.
An object representing an individual who can be contacted if the carriers have any questions about the business.
|
|
# File 'lib/surge_api/models/organization.rb', line 251
|
Instance Attribute Details
#email ⇒ String?
An email address at which the individual can be reached. Typically an email using the same domain name as the website URL will be preferred (e.g. with a website domain of ‘dtprecisionauto.com`, an email like `dom@dtprecisionauto.com` will be preferred over one like `dom@anothergarage.com` or `dom.toretto@gmail.com`)
218 |
# File 'lib/surge_api/models/organization.rb', line 218 required :email, String, nil?: true |
#first_name ⇒ String?
The first name (or given name) of the individual
224 |
# File 'lib/surge_api/models/organization.rb', line 224 required :first_name, String, nil?: true |
#last_name ⇒ String?
The last name (or family name) of the individual
230 |
# File 'lib/surge_api/models/organization.rb', line 230 required :last_name, String, nil?: true |
#phone_number ⇒ String?
A phone number at which the individual can be reached (E.164 format)
236 |
# File 'lib/surge_api/models/organization.rb', line 236 required :phone_number, String, nil?: true |
#title ⇒ Symbol, ...
The job title of the individual.
242 |
# File 'lib/surge_api/models/organization.rb', line 242 required :title, enum: -> { SurgeAPI::Organization::Contact::Title }, nil?: true |
#title_other ⇒ String?
If ‘other` is provided for the `title` field, this field should be used to provide the title of the individual
249 |
# File 'lib/surge_api/models/organization.rb', line 249 required :title_other, String, nil?: true |