Class: SurgeAPI::Models::PhoneNumber::Campaign
- Inherits:
-
Internal::Type::BaseModel
- Object
- Internal::Type::BaseModel
- SurgeAPI::Models::PhoneNumber::Campaign
- Defined in:
- lib/surge_api/models/phone_number.rb,
sig/surge_api/models/phone_number.rbs
Overview
Defined Under Namespace
Modules: AttachmentStatus
Instance Attribute Summary collapse
-
#attachment_status ⇒ Symbol, SurgeAPI::Models::PhoneNumber::Campaign::AttachmentStatus
The current campaign attachment status for this phone number.
-
#id ⇒ String
The unique identifier of the campaign this phone number is attached to.
Instance Method Summary collapse
-
#initialize(id:, attachment_status:) ⇒ Object
constructor
Campaign attachment details for a domestic local phone number.
- #to_hash ⇒ {
Methods inherited from Internal::Type::BaseModel
==, #==, #[], coerce, #deconstruct_keys, #deep_to_h, dump, fields, hash, #hash, inherited, inspect, #inspect, known_fields, optional, recursively_to_h, required, #to_h, #to_json, #to_s, to_sorbet_type, #to_yaml
Methods included from Internal::Type::Converter
#coerce, coerce, #dump, dump, #inspect, inspect, meta_info, new_coerce_state, type_info
Methods included from Internal::Util::SorbetRuntimeSupport
#const_missing, #define_sorbet_constant!, #sorbet_constant_defined?, #to_sorbet_type, to_sorbet_type
Constructor Details
#initialize(id:, attachment_status:) ⇒ Object
Campaign attachment details for a domestic local phone number
|
|
# File 'lib/surge_api/models/phone_number.rb', line 78
|
Instance Attribute Details
#attachment_status ⇒ Symbol, SurgeAPI::Models::PhoneNumber::Campaign::AttachmentStatus
The current campaign attachment status for this phone number.
76 |
# File 'lib/surge_api/models/phone_number.rb', line 76 required :attachment_status, enum: -> { SurgeAPI::PhoneNumber::Campaign::AttachmentStatus } |
#id ⇒ String
The unique identifier of the campaign this phone number is attached to
70 |
# File 'lib/surge_api/models/phone_number.rb', line 70 required :id, String |
Instance Method Details
#to_hash ⇒ {
60 |
# File 'sig/surge_api/models/phone_number.rbs', line 60
def to_hash: -> {
|