Class: SurgeAPI::Models::PhoneNumberAttachedToCampaignWebhookEvent::Data

Inherits:
Internal::Type::BaseModel show all
Defined in:
lib/surge_api/models/phone_number_attached_to_campaign_webhook_event.rb

Overview

See Also:

Defined Under Namespace

Modules: Type

Instance Attribute Summary collapse

Instance Method Summary collapse

Methods inherited from Internal::Type::BaseModel

==, #==, #[], coerce, #deconstruct_keys, #deep_to_h, dump, fields, hash, #hash, inherited, inspect, #inspect, known_fields, optional, recursively_to_h, required, #to_h, #to_json, #to_s, to_sorbet_type, #to_yaml

Methods included from Internal::Type::Converter

#coerce, coerce, #dump, dump, #inspect, inspect, meta_info, new_coerce_state, type_info

Methods included from Internal::Util::SorbetRuntimeSupport

#const_missing, #define_sorbet_constant!, #sorbet_constant_defined?, #to_sorbet_type, to_sorbet_type

Constructor Details

#initialize(id:, campaign_id:, name:, number:, type:) ⇒ Object

The data associated with the event

Parameters:

  • id (String)

    The unique identifier for the phone number

  • campaign_id (String)

    The unique identifier of the campaign this phone number is attached to

  • name (String, nil)

    A human-readable name for the phone number

  • number (String)

    The phone number in E.164 format

  • type (Symbol, SurgeAPI::Models::PhoneNumberAttachedToCampaignWebhookEvent::Data::Type)

    Whether the phone number is local, toll-free, or short code



# File 'lib/surge_api/models/phone_number_attached_to_campaign_webhook_event.rb', line 75

Instance Attribute Details

#campaign_idString

The unique identifier of the campaign this phone number is attached to

Returns:

  • (String)


55
# File 'lib/surge_api/models/phone_number_attached_to_campaign_webhook_event.rb', line 55

required :campaign_id, String

#idString

The unique identifier for the phone number

Returns:

  • (String)


49
# File 'lib/surge_api/models/phone_number_attached_to_campaign_webhook_event.rb', line 49

required :id, String

#nameString?

A human-readable name for the phone number

Returns:

  • (String, nil)


61
# File 'lib/surge_api/models/phone_number_attached_to_campaign_webhook_event.rb', line 61

required :name, String, nil?: true

#numberString

The phone number in E.164 format

Returns:

  • (String)


67
# File 'lib/surge_api/models/phone_number_attached_to_campaign_webhook_event.rb', line 67

required :number, String

#typeSymbol, SurgeAPI::Models::PhoneNumberAttachedToCampaignWebhookEvent::Data::Type

Whether the phone number is local, toll-free, or short code



73
# File 'lib/surge_api/models/phone_number_attached_to_campaign_webhook_event.rb', line 73

required :type, enum: -> { SurgeAPI::PhoneNumberAttachedToCampaignWebhookEvent::Data::Type }