Class: SurgeAPI::Models::PhoneNumberPurchaseParams
- Inherits:
-
Internal::Type::BaseModel
- Object
- Internal::Type::BaseModel
- SurgeAPI::Models::PhoneNumberPurchaseParams
- Extended by:
- Internal::Type::RequestParameters::Converter
- Includes:
- Internal::Type::RequestParameters
- Defined in:
- lib/surge_api/models/phone_number_purchase_params.rb
Overview
Defined Under Namespace
Modules: Type
Instance Attribute Summary collapse
-
#area_code ⇒ String?
The desired area code for this phone number.
-
#latitude ⇒ Float?
Latitude to search for nearby phone numbers.
-
#longitude ⇒ Float?
Longitude to search for nearby phone numbers.
-
#type ⇒ Symbol, ...
Whether the phone number is local or toll-free.
Attributes included from Internal::Type::RequestParameters
Instance Method Summary collapse
-
#initialize(area_code: nil, latitude: nil, longitude: nil, type: nil, request_options: {}) ⇒ Object
constructor
Some parameter documentations has been truncated, see PhoneNumberPurchaseParams for more details.
Methods included from Internal::Type::RequestParameters::Converter
Methods included from Internal::Type::RequestParameters
Methods inherited from Internal::Type::BaseModel
==, #==, #[], coerce, #deconstruct_keys, #deep_to_h, dump, fields, hash, #hash, inherited, inspect, #inspect, known_fields, optional, recursively_to_h, required, #to_h, #to_json, #to_s, to_sorbet_type, #to_yaml
Methods included from Internal::Type::Converter
#coerce, coerce, #dump, dump, #inspect, inspect, meta_info, new_coerce_state, type_info
Methods included from Internal::Util::SorbetRuntimeSupport
#const_missing, #define_sorbet_constant!, #sorbet_constant_defined?, #to_sorbet_type, to_sorbet_type
Constructor Details
#initialize(area_code: nil, latitude: nil, longitude: nil, type: nil, request_options: {}) ⇒ Object
Some parameter documentations has been truncated, see SurgeAPI::Models::PhoneNumberPurchaseParams for more details.
|
|
# File 'lib/surge_api/models/phone_number_purchase_params.rb', line 38
|
Instance Attribute Details
#area_code ⇒ String?
The desired area code for this phone number. If provided without type, the type will be inferred.
15 |
# File 'lib/surge_api/models/phone_number_purchase_params.rb', line 15 optional :area_code, String |
#latitude ⇒ Float?
Latitude to search for nearby phone numbers. Must be used with longitude. If provided without type, type will be inferred as ‘local’.
22 |
# File 'lib/surge_api/models/phone_number_purchase_params.rb', line 22 optional :latitude, Float |
#longitude ⇒ Float?
Longitude to search for nearby phone numbers. Must be used with latitude. If provided without type, type will be inferred as ‘local’.
29 |
# File 'lib/surge_api/models/phone_number_purchase_params.rb', line 29 optional :longitude, Float |
#type ⇒ Symbol, ...
Whether the phone number is local or toll-free. Can be omitted if area_code or latitude/longitude are provided.
36 |
# File 'lib/surge_api/models/phone_number_purchase_params.rb', line 36 optional :type, enum: -> { SurgeAPI::PhoneNumberPurchaseParams::Type } |